@@ -18,6 +18,7 @@
 #include "mem.h"
 #include <fcntl.h>
 #include <signal.h>
+#include <stdbool.h>
 #include <string.h>
 #include <sys/wait.h>
 #ifndef HAVE_TERMIOS_H
@@ -34,6 +35,7 @@
 #define FORK fork
 #endif
 #include <netdb.h>
+#include <unistd.h>
 
 /* AI_NUMERICSERV as a value for the `ai_flags' member
  * of `struct addrinfo' of header <netdb.h> has only
@@ -55,10 +57,6 @@
 #define AI_NUMERICSERV 0
 #endif
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
 io_t *iop;
 int ion;
 
@@ -80,7 +78,7 @@ void IOinit (void) {
     if (!(shell = getenv ("SHELL")))
         shell = "/bin/sh";
     if (shell[0] != '/' && shell[0] != '.') {
-        if (!(shell = buildpath (shell, TRUE)))
+        if (!(shell = buildpath (shell, true)))
             shell = "/bin/sh";
         else
             shell = strdup (shell);
@@ -170,7 +168,7 @@ int IOopen (char *kind, char *name, char *mode, char *fmt) {
                     return -1;
                 break;
             }
-            path = buildpath (name, FALSE);
+            path = buildpath (name, false);
             if (!path || !(p->ifp = p->ofp = fopen (path, mode)))
                 return -1;
         }
@@ -179,7 +177,7 @@ int IOopen (char *kind, char *name, char *mode, char *fmt) {
         if (!fmt)
             fmt = "%e";
         if (
-            !(path = buildpath (name, TRUE)) ||
+            !(path = buildpath (name, true)) ||
             !(command = buildcommand (path, NULL, -1, -1, fmt))
         )
             return -1;
@@ -191,7 +189,7 @@ int IOopen (char *kind, char *name, char *mode, char *fmt) {
         if (!fmt)
             fmt = "%e";
         if (
-            !(path = buildpath (name, TRUE)) ||
+            !(path = buildpath (name, true)) ||
             !(command = buildcommand (path, NULL, -1, -1, fmt))
         )
             return -1;
@@ -216,7 +214,7 @@ int IOopen (char *kind, char *name, char *mode, char *fmt) {
         if (listen (sfd, 5) < 0)
             return -1;
         gethostname (hname, sizeof (hname));
-        if (!(path = buildpath (name, TRUE)) || !(command = buildcommand (
+        if (!(path = buildpath (name, true)) || !(command = buildcommand (
             path, hname, (int) ntohs (sname.sin_port),
             (int) ntohs (sname.sin_port), fmt
         )))
