@@ -13,10 +13,8 @@
 #include "smyrnadefs.h"
 #include <cgraph/cgraph.h>
 
-extern char *xml_string(char *s);
 extern int l_int(void *obj, Agsym_t * attr, int def);
 extern float l_float(void *obj, Agsym_t * attr, float def);
-extern int mapbool(char *p);
 extern int getAttrBool(Agraph_t* g,void* obj,char* attr_name,int def);
 extern int getAttrInt(Agraph_t* g,void* obj,char* attr_name,int def);
 extern float getAttrFloat(Agraph_t* g,void* obj,char* attr_name,float def);
