@@ -18,18 +18,13 @@
 
 #include <xdot/xdot.h>
 #include <gtk/gtk.h>
-#include <GL/gl.h>
-#include <GL/glu.h>
+#include <glcomp/opengl.h>
 #include <gtk/gtkgl.h>
 #include <cgraph/cgraph.h>
 #include <glcomp/glcompset.h>
 #include "hier.h"
 #include <glcomp/glutils.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #ifdef	_WIN32			//this is needed on _WIN32 to get libglade see the callback
 #define _BB  __declspec(dllexport)
 #else
@@ -101,19 +96,6 @@ typedef struct
 	int with_widgets;
 }attr_list;
 
-
-    typedef enum { leftmousebutton, rightmousebutton,
-	    thirdmousebutton } clicked_mouse_button;
-    typedef enum { MOUSE_ROTATE_X, MOUSE_ROTATE_Y, MOUSE_ROTATE_XY,
-	    MOUSE_ROTATE_Z } mouse_rotate_axis;
-
-
-    typedef struct
-    {
-	unsigned char *data;
-	int w;
-	int h;
-    }image_data;
     typedef struct 
     {
 	xdot_op op;
@@ -123,31 +105,14 @@ typedef struct
 	int layer;
 	int listId;/*opengl list id*/
 	glCompImage* img;
-	/* image_data iData; */
     } sdot_op;	
 	
-	
-
-#define MAX_BTN_CNT 50
     typedef struct {
 	float perc;
 	glCompColor c;
 
     } colorschema;
 
-    typedef enum { gvpr_no_arg,gvpr_obj_arg,gvpr_string_arg,gvpr_sel_node_arg,gvpr_sel_edge_arg} gvpr_arg_type;
-
-    typedef struct {
-	char* def;
-	char *script;
-	char *args;
-	char *attr_name;	/*attribute name to identify script in the graph */
-	void* obj;
-	gvpr_arg_type arg_type;
-    } gvprscript;
-    //_on_click="(gvpr_no_arg)N{node.color="red"){N.color="blue"}";
-
-
     typedef struct {
 	int schemacount;       /* number of colors */
 	int smooth;            /* if true, interpolate */
@@ -172,23 +137,6 @@ typedef struct
 	GVK_SFDP		/* keep last */
     } gvk_layout;
 
-    typedef struct {
-	int anglex;
-	int angley;
-	int anglez;
-    } rotation;
-
-    typedef struct {
-	int anglex;
-	int angley;
-	int anglez;
-    } gl3DNav;
-
-
-    typedef struct {
-
-	    int a;
-    } topviewdata;
     typedef struct
     {
 	int node_id;
@@ -199,13 +147,10 @@ typedef struct
 	int edgelabel_id;
     }topviewcache;
 
-    typedef struct xdot_set xdot_set;
-    typedef enum { GEpixels, GEinches, GEmm } GEunit;
     typedef struct {
 	int color;
 	int pos;
 	int selection;
-	int visibility;
 	int nodesize;
 
 
@@ -222,39 +167,6 @@ typedef struct
 	smyrna_view_mode mode;
     }mouse_action_t;
 
-    typedef struct _object_data	//has to be attached to every Node, Edge, Graph and cluster
-    {
-	Agrec_t h;
-	int ID;
-	char *ObjName;
-	int ObjType;
-	int Layer;
-	int Visible;
-	int Selected;
-	int NumDataCount;
-	float *NumData;
-	int StrDataCount;
-	char **StrData;
-	int param;		//generic purpose param
-	int TVRef;		//Topview reference
-	int edgeid;		/*for only edges,  > 0  multiedges */
-
-    } element_data;
-    typedef struct _temp_node_record	//helper record to identofy head and tail of edges
-    {
-	Agrec_t h;
-	int ID;
-	int TVref;		//topview data structure reference
-    } temp_node_record;
-
-#define OD_Visible(p) (p.data.Visible)
-#define OD_Locked(p) (p.data.Locked)
-#define OD_Highlighted(p) (p.data.Highlighted)
-
-
-
-    typedef enum { CAM_PERSPECTIVE, CAM_ORTHO } cam_t;
-
     typedef struct _viewport_camera {
 	float x;
 	float y;
@@ -263,75 +175,13 @@ typedef struct
 	float targetx;
 	float targety;
 	float targetz;
-	int index;
-	float anglexy;
-	float anglexyz;
 
-	float anglex;
-	float angley;
-	float anglez;
-
-
-	float camera_vectorx;
-	float camera_vectory;
-	float camera_vectorz;
 	float r;
-
-
-	cam_t type;		//
     } viewport_camera;
 
-
-
-    typedef struct 
-	{
-		Agnode_t *Node;
-		/*original coordinates */
-		float x;
-		float y;
-		float z;
-		/*coordinates to draw */
-		float distorted_x;
-		float distorted_y;
-		float distorted_z;
-		float zoom_factor;
-		int in_fish_eye;	//boolean value if to apply fisheye
-		glCompColor Color;
-		char *Label;
-		char *Label2;
-		int degree;
-		float node_alpha;
-		int valid;
-		element_data data;
-		float size;
-		xdot* xDot;
-    } topview_node;
-
-    typedef struct 
-	{
-		Agedge_t *Edge;		//edge itself
-		float x1;
-		float y1;
-		float z1;
-		float x2;
-		float y2;
-		float z2;
-		float length;
-		topview_node *Node1;	//Tail
-		topview_node *Node2;	//Head
-		glCompColor Color;
-		element_data data;
-		xdot* xDot;
-    } topview_edge;
-
     typedef struct _graph_data {
 	Agrec_t h;
 	char *GraphFileName;
-	//graph's location, change these to move the whole graph
-	int Modified;		//if graph has been modified after loading
-	float offsetx;
-	float offsety;
-	float offsetz;
     } graph_data;
 
 
@@ -358,13 +208,9 @@ typedef struct
 	glCompPoint posTail;
 	glCompPoint posHead;
 	int selected;
-	int visible;
-	int printLabel;
     }edgeRec;
 #define EREC(e) ((edgeRec*)(aggetrec(e,"edgeRec",0)))
-#define ED_visible(e) (EREC(e)->visible)
 #define ED_selected(e) (EREC(e)->selected)
-#define ED_printLabel(e) (EREC(e)->printLabel)
 #define ED_posTail(e) (EREC(e)->posTail)
 #define ED_posHead(e) (EREC(e)->posHead)
 
@@ -409,12 +255,7 @@ typedef struct
     } selection;
 
     typedef struct {
-	topview_node *Nodes;
-	topview_edge *Edges;
 	int Nodecount;
-	int Edgecount;
-	topviewdata *TopviewData;
-	void *customptr;
 	struct {
 	    int active;	//1 draw hierarchy 0 draw regular topview
 	    reposition_t repos;
@@ -427,17 +268,9 @@ typedef struct
 	    focus_t *fs;
     	} fisheyeParams;
 
-	topview_node **picked_nodes;
-	int picked_node_count;
-	topview_edge **picked_edges;
-	int picked_edge_count;
-
 	graph_data Graphdata;
-	int maxnodedegree;
 	float maxedgelen;
 	float minedgelen;
-	float avgedgelength;
-	float init_zoom;
 	float fitin_zoom;
 	xdot* xDot;
 	float global_z;
@@ -445,24 +278,14 @@ typedef struct
 	attr_list* filtered_attr_list;
 
 	topviewcache cache;
-	int xdotId;
 	selection sel;
 	
     } topview;
 
-
-
-    enum {
-	COL_NAME = 0,
-	COL_FILENAME,
-	NUM_COLS
-    };
-
     typedef struct _attribute {
 	char Type;
 	char *Name;
 	char *Default;
-	char ApplyTo[GVE_EDGE + 1];
 	char Engine[GVK_FDP + 1];
 	char **ComboValues;
 	int ComboValuesCount;
@@ -501,7 +324,7 @@ typedef struct
 	float zoom;
 
 	/*clipping coordinates, to avoid unnecesarry rendering */
-	float clipX1, clipX2, clipY1, clipY2, clipZ1, clipZ2;
+	float clipX1, clipX2, clipY1, clipY2;
 
 	/*background color */
 	glCompColor bgColor;
@@ -547,9 +370,6 @@ typedef struct
 	float bdxLeft, bdyTop;
 	float bdxRight, bdyBottom;
 
-	/*reserved , not being used yet */
-	GEunit unit;		//default pixels :0  
-
 	/*screen window size in 2d */
 	int w, h;
 	/*graph pointer to hold loaded graphs */
@@ -611,7 +431,6 @@ typedef struct
 	int initFile;
 	int drawSplines;
 	colorschemaset *colschms;
-	char* temp;
 	char *template_file;
 	GtkComboBox *graphComboBox;	/*pointer to graph combo box at top right */
 	ArcBall_t *arcball;
@@ -630,10 +449,5 @@ typedef struct
     extern ViewInfo *view;
     extern GtkMessageDialog *Dlg;
     extern char *smyrnaPath(char *suffix);
-    extern char *smyrnaGlade;
 
     extern void glexpose(void);
-
-#ifdef __cplusplus
-}				/* end extern "C" */
-#endif
