@@ -19,7 +19,11 @@
 #include <glcomp/glutils.h>
 #include "selectionfuncs.h"
 #include <common/memory.h>
+#include <common/types.h>
+#include <common/utils.h>
 #include <ctype.h>
+#include <float.h>
+#include <math.h>
 
 static xdot *parseXdotwithattrs(void *e)
 {
@@ -45,33 +49,21 @@ static xdot *parseXdotwithattrs(void *e)
 
 }
 
-static void set_boundaries(Agraph_t * g, topview * t)
+static void set_boundaries(Agraph_t * g)
 {
     Agnode_t *v;
     Agsym_t* pos_attr = GN_pos(g);
     glCompPoint pos;
-    float left, right, top, bottom;
-    int id=0;
+    float left = FLT_MAX, right = -FLT_MAX, top = FLT_MAX, bottom = -FLT_MAX;
 
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) 
     {
 	pos=getPointFromStr(agxget(v, pos_attr));
-	if(id==0)
-	{
-	    left=pos.x;
-	    right=pos.x;
-	    top=pos.y;
-	    bottom=pos.y;
-	}
-	if (left > pos.x)
-	    left = pos.x;
-	if (right < pos.x)
-	    right = pos.x;
-	if (bottom > pos.y)
-	    bottom = pos.y;
-	if (top < pos.y)
-	    top = pos.y;
-	id++;
+
+	left = fminf(left, pos.x);
+	right = fmaxf(right, pos.x);
+	top = fmaxf(top, pos.y);
+	bottom = fminf(bottom, pos.y);
     }
     view->bdxLeft = left;
     view->bdyTop = top;
@@ -622,11 +614,8 @@ static void renderEdgesFn (Agraph_t * g, edgefn ef, int skipSelected)
 		continue;
 
 	    if(!object_color(e,&c)) {
-		ED_visible(e) = 0;
 		continue;
 	    }
-	    else
-		ED_visible(e) = 1;
 	    if (ED_selected(e) && skipSelected)
 		continue;
 
@@ -637,6 +626,9 @@ static void renderEdgesFn (Agraph_t * g, edgefn ef, int skipSelected)
 
 static void edge_xdot (Agraph_t* g, Agedge_t* e, glCompColor c)
 {
+    (void)g;
+    (void)c;
+
     xdot * x;
     x=parseXdotwithattrs(e);
     draw_xdot(x,0);
@@ -694,7 +686,6 @@ static void renderNodeLabels(Agraph_t * g)
     glCompPoint pos;
     Agsym_t* data_attr = GN_labelattribute(g);
     Agsym_t* l_color_attr = GG_nodelabelcolor(g);
-    GLfloat nodeSize;
     glCompColor c;
 
     glCompColorxlate(&c,agxget(g,l_color_attr));
@@ -707,7 +698,6 @@ static void renderNodeLabels(Agraph_t * g)
 	    continue;
 
 	pos = ND_A(v);
-	nodeSize = ND_size(v);
 	glColor4f(c.R,c.G,c.B,c.A);
 	if(!data_attr)
             glprintfglut(view->glutfont,pos.x,pos.y,pos.z,agnameof(v));
@@ -827,15 +817,9 @@ void updateSmGraph(Agraph_t * g,topview* t)
     float totalELength=0;
 
     t->Nodecount=0;
-    t->Edgecount=0;
-    t->avgedgelength=0;
     t->maxedgelen=0;
     t->minedgelen=-1;
 
-    t->picked_node_count = 0;
-    t->picked_nodes = '\0';
-    t->picked_edge_count = 0;
-    t->picked_edges = '\0';
     t->global_z=0;
     t->sel.selPoly.cnt=0;
     t->sel.selPoly.pts=NULL;
@@ -846,7 +830,6 @@ void updateSmGraph(Agraph_t * g,topview* t)
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
 	for (e = agfstout(g, v); e; e = agnxtout(g, e)) 
 	{
-	    t->Edgecount++;
 	    eLength=getEdgeLength(e);
 	    if((t->minedgelen == -1) || (t->minedgelen > eLength))
 		t->minedgelen=eLength;
@@ -860,8 +843,7 @@ void updateSmGraph(Agraph_t * g,topview* t)
     aginit(g, AGNODE, "nodeRec", sizeof(nodeRec), 0);
     aginit(g, AGEDGE, "edgeRec", sizeof(edgeRec), 0);
 
-    set_boundaries(g,t);
-    t->avgedgelength = totalELength / t->Edgecount;
+    set_boundaries(g);
     view->Topview=t;
 
 
@@ -876,16 +858,12 @@ void updateSmGraph(Agraph_t * g,topview* t)
 }
 void initSmGraph(Agraph_t * g,topview* rv)
 {
-    rv->maxnodedegree = 1;
-
-        
-
     /*create attribute list*/
     rv->attributes=load_attr_list(view->g[view->activeGraph]);
     rv->filtered_attr_list=NULL;
 
-    /*set topologilca fisheye to NULL */
-    rv->fisheyeParams.h = '\0';
+    // set topological fisheye to NULL
+    rv->fisheyeParams.h = NULL;
 
     rv->fisheyeParams.active = 0;
     rv->cache.node_id=-1;
@@ -898,7 +876,7 @@ void initSmGraph(Agraph_t * g,topview* rv)
     updateSmGraph(g,rv);
 }
 
-void renderSmGraph(Agraph_t * g,topview* t)
+void renderSmGraph(topview* t)
 {
     /*
 	we like to have blending affect where node and edge  overlap
@@ -933,7 +911,3 @@ void renderSmGraph(Agraph_t * g,topview* t)
     }
 
 }
-
-void freeSmGraph(Agraph_t * g,topview* t)
-{
-}
