@@ -8,17 +8,15 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "config.h"
-
 #include "gml2gv.h"
 #include <stdlib.h>
 #include <string.h>
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
 
 #include <getopt.h>
 
+#include <cgraph/exit.h>
+#include <cgraph/unreachable.h>
+
 #define N_NEW(n,t)       calloc((n),sizeof(t))
 
 static int Verbose;
@@ -51,21 +49,16 @@ static FILE *getFile(void)
     return rv;
 }
 
-static FILE *openFile(char *name, char *mode)
+static FILE *openFile(const char *name)
 {
     FILE *fp;
-    char *modestr;
 
-    fp = fopen(name, mode);
+    fp = fopen(name, "w");
     if (!fp) {
-        if (*mode == 'r')
-            modestr = "reading";
-        else
-            modestr = "writing";
-        fprintf(stderr, "%s: could not open file %s for %s\n",
-                CmdName, name, modestr);
+        fprintf(stderr, "%s: could not open file %s for writing\n",
+                CmdName, name);
         perror(name);
-        exit(1);
+        graphviz_exit(1);
     }
     return fp;
 }
@@ -81,7 +74,7 @@ If no files are specified, stdin is used\n";
 static void usage(int v)
 {
     printf(useString, CmdName);
-    exit(v);
+    graphviz_exit(v);
 }
 
 static char *cmdName(char *path)
@@ -113,7 +106,7 @@ static void initargs(int argc, char **argv)
 	case 'o':
 	    if (outFile != NULL)
 		fclose(outFile);
-	    outFile = openFile(optarg, "w");
+	    outFile = openFile(optarg);
 	    break;
 	case ':':
 	    fprintf(stderr, "%s: option -%c missing argument\n", CmdName, optopt);
@@ -127,6 +120,9 @@ static void initargs(int argc, char **argv)
 			optopt);
 		usage(1);
 	    }
+	    break;
+	default:
+	    UNREACHABLE();
 	}
     }
 
@@ -181,6 +177,6 @@ int main(int argc, char **argv)
 	    fflush(outFile);
 	}
     }
-    exit(rv);
+    graphviz_exit(rv);
 }
 
