@@ -33,14 +33,26 @@
 #define EX_DATAERR		65
 #define EX_NOINPUT		66
 #define EX_UNAVAILABLE	69
+#define EX_OSERR	71
 #else
 #include <sysexits.h>
 #endif
 #include <gd.h>
 #include <stdbool.h>
 
+#include <cgraph/exit.h>
+
 static char *pstopng="gs -dNOPAUSE -sDEVICE=pngalpha -sOutputFile=- -q -";
 
+static void *xmalloc(size_t size) {
+  void *p = malloc(size);
+  if (size > 0 && p == NULL) {
+    fprintf(stderr, "Out of memory\n");
+    graphviz_exit(EX_OSERR);
+  }
+  return p;
+}
+
 static gdImagePtr imageLoad (char *filename)
 {
     FILE *f;
@@ -52,20 +64,20 @@ static gdImagePtr imageLoad (char *filename)
     ext = strrchr(filename, '.');
     if (!ext) {
         fprintf(stderr, "Filename \"%s\" has no file extension.\n", filename);
-        exit(EX_USAGE);
+        graphviz_exit(EX_USAGE);
     }
     rc = stat(filename, &statbuf);
     if (rc) {
 	 fprintf(stderr, "Failed to stat \"%s\"\n", filename);
-         exit(EX_NOINPUT);
+         graphviz_exit(EX_NOINPUT);
     }
     if (strcasecmp(ext, ".ps") == 0) {
 	ext = ".png";
-	tmp = malloc(strlen(filename) + strlen(ext) + 1);
+	tmp = xmalloc(strlen(filename) + strlen(ext) + 1);
 	strcpy(tmp,filename);
 	strcat(tmp,ext);
 	
-	cmd = malloc(strlen(pstopng) + 2 + strlen(filename) + 2 + strlen(tmp) + 1);
+	cmd = xmalloc(strlen(pstopng) + 2 + strlen(filename) + 2 + strlen(tmp) + 1);
 	strcpy(cmd,pstopng);
 	strcat(cmd," <");
 	strcat(cmd,filename);
@@ -78,14 +90,14 @@ static gdImagePtr imageLoad (char *filename)
 	free(tmp);
         if (!f) {
             fprintf(stderr, "Failed to open converted \"%s%s\"\n", filename, ext);
-            exit(EX_NOINPUT);
+            graphviz_exit(EX_NOINPUT);
         }
     }
     else {
         f = fopen(filename, "rb");
         if (!f) {
             fprintf(stderr, "Failed to open \"%s\"\n", filename);
-            exit(EX_NOINPUT);
+            graphviz_exit(EX_NOINPUT);
         }
     }
     im = 0;
@@ -94,7 +106,7 @@ static gdImagePtr imageLoad (char *filename)
         im = gdImageCreateFromPng(f);
 #else
         fprintf(stderr, "PNG support is not available\n");
-        exit(EX_UNAVAILABLE);
+        graphviz_exit(EX_UNAVAILABLE);
 #endif
     }
     else if (strcasecmp(ext, ".gif") == 0) {
@@ -102,7 +114,7 @@ static gdImagePtr imageLoad (char *filename)
         im = gdImageCreateFromGif(f);
 #else
         fprintf(stderr, "GIF support is not available\n");
-        exit(EX_UNAVAILABLE);
+        graphviz_exit(EX_UNAVAILABLE);
 #endif
     }
     else if (strcasecmp(ext, ".jpg") == 0) {
@@ -110,13 +122,13 @@ static gdImagePtr imageLoad (char *filename)
         im = gdImageCreateFromJpeg(f);
 #else
         fprintf(stderr, "JPEG support is not available\n");
-        exit(EX_UNAVAILABLE);
+        graphviz_exit(EX_UNAVAILABLE);
 #endif
     }
     fclose(f);
     if (!im) {
         fprintf(stderr, "Loading image from file  \"%s\" failed!\n", filename);
-        exit(EX_DATAERR);
+        graphviz_exit(EX_DATAERR);
     }
     return im;
 }
@@ -152,11 +164,11 @@ int main(int argc, char **argv)
 
     if (argc == 2 && strcmp(argv[1], "-?") == 0) {
         fprintf(stderr, "Usage: diffimg image1 image2 [outimage]\n");
-        exit(0);
+        graphviz_exit(0);
     }
     if (argc < 3) {
         fprintf(stderr, "Usage: diffimg image1 image2 [outimage]\n");
-        exit(EX_USAGE);
+        graphviz_exit(EX_USAGE);
     }
     A = imageLoad(argv[1]);
     B = imageLoad(argv[2]);
@@ -192,6 +204,6 @@ int main(int argc, char **argv)
     gdImageDestroy(B);
     gdImageDestroy(C);
 
-    return (rc ? EXIT_FAILURE : EXIT_SUCCESS);
+    graphviz_exit(rc ? EXIT_FAILURE : EXIT_SUCCESS);
 }
 
