@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <stddef.h>
 #include <stdio.h>
 #include <cgraph/cghdr.h>
 #if defined(_WIN32)
@@ -23,22 +24,20 @@ static int iofread(void *chan, char *buf, int bufsize)
 }
 
 /* default IO methods */
-static int ioputstr(void *chan, const char *str)
-{
-    return fputs(str, chan);
-}
 
 static int ioflush(void *chan)
 {
     return fflush(chan);
 }
 
-Agiodisc_t AgIoDisc = { iofread, ioputstr, ioflush };
+typedef int (*printfn)(void *chan, const char *format, ...);
+
+Agiodisc_t AgIoDisc = { iofread, (printfn)fprintf, ioflush };
 
 typedef struct {
     const char *data;
-    int len;
-    int cur;
+    size_t len;
+    size_t cur;
 } rdr_t;
 
 static int
@@ -67,7 +66,7 @@ memiofread(void *chan, char *buf, int bufsize)
 	 * null-terminated strings.
 	 */
     } while (c != '\n' && l < bufsize && (c = *ptr++));
-    s->cur += l;
+    s->cur += (size_t)l;
     return l;
 }
 
@@ -79,7 +78,7 @@ static Agraph_t *agmemread0(Agraph_t *arg_g, const char *cp)
     rdr_t rdr;
     Agdisc_t disc;
 
-    memIoDisc.putstr = AgIoDisc.putstr;
+    memIoDisc.printf = AgIoDisc.printf;
     memIoDisc.flush = AgIoDisc.flush;
     rdr.data = cp;
     rdr.len = strlen(cp);
