@@ -15,7 +15,9 @@
 #include <gvc/gvc.h>
 #include <xdot/xdot.h>
 #include <cgraph/agxbuf.h>
+#include <cgraph/exit.h>
 #include <cgraph/strcasecmp.h>
+#include <stdbool.h>
 #include <stddef.h>
 #include <string.h>
 
@@ -90,7 +92,7 @@ int dotneato_usage(int exval)
     fputs(configItems, outs);
 
     if (GvExitOnUsage && (exval >= 0))
-	exit(exval);
+	graphviz_exit(exval);
     return (exval+1);
 	
 }
@@ -144,12 +146,12 @@ static char* dotneato_basename (char* path)
     while (*s) s++;
     s--;
     /* skip over trailing slashes, nulling out as we go */
-    while ((s > path) && ((*s == '/') || (*s == '\\')))
+    while (s > path && (*s == '/' || *s == '\\'))
 	*s-- = '\0';
     if (s == path) ret = path;
     else {
-	while ((s > path) && ((*s != '/') && (*s != '\\'))) s--;
-	if ((*s == '/') || (*s == '\\')) ret = s+1;
+	while (s > path && (*s != '/' && *s != '\\')) s--;
+	if (*s == '/' || *s == '\\') ret = s+1;
 	else ret = path;
     }
 #ifdef _WIN32
@@ -175,9 +177,7 @@ static void use_library(GVC_t *gvc, const char *name)
     gvc->common.lib = Lib;
 }
 
-static void global_def(agxbuf* xb, char *dcl, int kind,
-         attrsym_t * ((*dclfun) (Agraph_t *, int kind, char *, char *)) )
-{
+static void global_def(agxbuf* xb, char *dcl, int kind) {
     char *p;
     char *rhs = "true";
 
@@ -188,7 +188,7 @@ static void global_def(agxbuf* xb, char *dcl, int kind,
     }
     else
 	agxbput (xb, dcl);
-    sym = dclfun(NULL, kind, agxbuse (xb), rhs);
+    sym = agattr(NULL, kind, agxbuse (xb), rhs);
     sym->fixed = 1;
 }
 
@@ -227,7 +227,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
     char c, *rest, *layout;
     const char *val;
     int i, v, nfiles;
-    unsigned char buf[SMALLBUF];
+    char buf[SMALLBUF];
     agxbuf xb;
     int Kflag = 0;
 
@@ -249,7 +249,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
     /* must happen before trying to select any plugins */
     if (gvc->common.config) {
         gvconfig(gvc, gvc->common.config);
-	exit (0);
+	graphviz_exit(0);
     }
 
     /* feed the globals */
@@ -265,11 +265,11 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
     agxbinit(&xb, SMALLBUF, buf);
     for (i = 1; i < argc; i++) {
 	if (argv[i] && argv[i][0] == '-') {
-	    rest = &(argv[i][2]);
+	    rest = &argv[i][2];
 	    switch (c = argv[i][1]) {
 	    case 'G':
 		if (*rest)
-		    global_def(&xb, rest, AGRAPH, agattr);
+		    global_def(&xb, rest, AGRAPH);
 		else {
 		    fprintf(stderr, "Missing argument for -G flag\n");
 		    return (dotneato_usage(1));
@@ -277,7 +277,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		break;
 	    case 'N':
 		if (*rest)
-		    global_def(&xb, rest, AGNODE,agattr);
+		    global_def(&xb, rest, AGNODE);
 		else {
 		    fprintf(stderr, "Missing argument for -N flag\n");
 		    return (dotneato_usage(1));
@@ -285,7 +285,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		break;
 	    case 'E':
 		if (*rest)
-		    global_def(&xb, rest, AGEDGE,agattr);
+		    global_def(&xb, rest, AGEDGE);
 		else {
 		    fprintf(stderr, "Missing argument for -E flag\n");
 		    return (dotneato_usage(1));
@@ -297,8 +297,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		    fprintf(stderr, "Missing argument for -T flag\n");
 		    return (dotneato_usage(1));
 		}
-		v = gvjobs_output_langname(gvc, val);
-		if (!v) {
+		if (!gvjobs_output_langname(gvc, val)) {
 		    /* TODO: Detect empty results from gvplugin_list() and prompt to configure with '-c' */
 		    char *fmts;
 		    fprintf(stderr, "Format: \"%s\" not recognized.", val);
@@ -309,7 +308,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 			/* Q: Should 'dot -c' be suggested generally or only when val = "dot"? */
 			fprintf(stderr, " No formats found.\nPerhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
 		    }
-		    if (GvExitOnUsage) exit(1);
+		    if (GvExitOnUsage) graphviz_exit(1);
 		    return(2);
 		}
 		break;
@@ -337,7 +336,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 			    fprintf(stderr, " No layouts found.\nPerhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
 			}
 		    }
-		    if (GvExitOnUsage) exit(1);
+		    if (GvExitOnUsage) graphviz_exit(1);
 		    return(2);
                 }
 		Kflag = 1;
@@ -349,7 +348,7 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		fprintf(stderr, "%s - %s version %s (%s)\n",
 			gvc->common.cmdname, gvc->common.info[0], 
 			gvc->common.info[1], gvc->common.info[2]);
-		if (GvExitOnUsage) exit(0);
+		if (GvExitOnUsage) graphviz_exit(0);
 		return (1);
 		break;
 	    case 'l':
@@ -444,16 +443,14 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		}
 	    }
 
-	    if (GvExitOnUsage) exit(1);
+	    if (GvExitOnUsage) graphviz_exit(1);
 	    return(2);
 	}
     }
 
     /* if no -Txxx, then set default format */
     if (!gvc->jobs || !gvc->jobs->output_langname) {
-	v = gvjobs_output_langname(gvc, "dot");
-	if (!v) {
-//	assert(v);  /* "dot" should always be available as an output format */
+	if (!gvjobs_output_langname(gvc, "dot")) {
 		fprintf(stderr,
 			"Unable to find even the default \"-Tdot\" renderer.  Has the config\nfile been generated by running \"dot -c\" with installer's privileges?\n");
 			return(2);
@@ -471,28 +468,27 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
  * If only one number is given, it is used for both x and y.
  * Returns true if the attribute ends in '!'.
  */
-static boolean getdoubles2ptf(graph_t * g, char *name, pointf * result)
-{
+static bool getdoubles2ptf(graph_t *g, char *name, pointf *result) {
     char *p;
     int i;
     double xf, yf;
     char c = '\0';
-    boolean rv = FALSE;
+    bool rv = false;
 
     if ((p = agget(g, name))) {
 	i = sscanf(p, "%lf,%lf%c", &xf, &yf, &c);
-	if ((i > 1) && (xf > 0) && (yf > 0)) {
+	if (i > 1 && xf > 0 && yf > 0) {
 	    result->x = POINTS(xf);
 	    result->y = POINTS(yf);
 	    if (c == '!')
-		rv = TRUE;
+		rv = true;
 	}
 	else {
 	    c = '\0';
 	    i = sscanf(p, "%lf%c", &xf, &c);
-	    if ((i > 0) && (xf > 0)) {
+	    if (i > 0 && xf > 0) {
 		result->y = result->x = POINTS(xf);
-		if (c == '!') rv = TRUE;
+		if (c == '!') rv = true;
 	    }
 	}
     }
@@ -510,57 +506,6 @@ void getdouble(graph_t * g, char *name, double *result)
     }
 }
 
-#ifdef EXPERIMENTAL_MYFGETS
-/*
- * Potential input filter - e.g. for iconv 
- */
-
-/*
- * myfgets - same api as fgets
- * 
- * gets n chars at a time
- *
- * returns pointer to user buffer,
- * or returns NULL on eof or error.
- */
-static char *myfgets(char * ubuf, int n, FILE * fp)
-{
-    static char *buf;
-    static int bufsz, pos, len;
-    int cnt;
-
-    if (!n) {                   /* a call with n==0 (from aglexinit) resets */
-        ubuf[0] = '\0';
-        pos = len = 0;
-        return NULL;
-    }
-
-    if (!len) {
-	if (n > bufsz) {
-	    bufsz = n;
-	    buf = realloc(buf, bufsz);
-	}
-	if (!(fgets(buf, bufsz, fp))) {
-            ubuf[0] = '\0';
-            return NULL;
-        }
-	len = strlen(buf);
-	pos = 0;
-    }
-
-    cnt = n - 1;
-    if (len < cnt)
-	cnt = len;
-
-    memcpy(ubuf, buf + pos, cnt);
-    pos += cnt;
-    len -= cnt;
-    ubuf[cnt] = '\0';
-
-    return ubuf;
-}
-#endif
-
 graph_t *gvNextInputGraph(GVC_t *gvc)
 {
     graph_t *g = NULL;
@@ -588,11 +533,7 @@ graph_t *gvNextInputGraph(GVC_t *gvc)
 	    agsetfile(fn ? fn : "<stdin>");
 	    oldfp = fp;
 	}
-#ifdef EXPERIMENTAL_MYFGETS
-	g = agread_usergets(fp, myfgets);
-#else
 	g = agread(fp,NULL);
-#endif
 	if (g) {
 	    gvg_init(gvc, g, fn, gidx++);
 	    break;
@@ -645,7 +586,7 @@ static void setRatio(graph_t * g)
     char *p, c;
     double ratio;
 
-    if ((p = agget(g, "ratio")) && ((c = p[0]))) {
+    if ((p = agget(g, "ratio")) && (c = p[0])) {
 	switch (c) {
 	case 'a':
 	    if (streq(p, "auto"))
@@ -678,7 +619,7 @@ static void setRatio(graph_t * g)
 	cgraph requires 
 
 */
-void graph_init(graph_t * g, boolean use_rankdir)
+void graph_init(graph_t * g, bool use_rankdir)
 {
     char *p;
     double xf;
@@ -757,7 +698,7 @@ void graph_init(graph_t * g, boolean use_rankdir)
 		xf = MIN_RANKSEP;
 	}
 	if (strstr(p, "equally"))
-	    GD_exact_ranksep(g) = TRUE;
+	    GD_exact_ranksep(g) = true;
     } else
 	xf = DEFAULT_RANKSEP;
     GD_ranksep(g) = POINTS(xf);
@@ -767,23 +708,22 @@ void graph_init(graph_t * g, boolean use_rankdir)
     GD_fontnames(g) = maptoken(p, fontnamenames, fontnamecodes);
 
     setRatio(g);
-    GD_drawing(g)->filled =
-	getdoubles2ptf(g, "size", &(GD_drawing(g)->size));
+    GD_drawing(g)->filled = getdoubles2ptf(g, "size", &GD_drawing(g)->size);
     getdoubles2ptf(g, "page", &(GD_drawing(g)->page));
 
     GD_drawing(g)->centered = mapbool(agget(g, "center"));
 
     if ((p = agget(g, "rotate")))
-	GD_drawing(g)->landscape = (atoi(p) == 90);
+	GD_drawing(g)->landscape = atoi(p) == 90;
     else if ((p = agget(g, "orientation")))
-	GD_drawing(g)->landscape = ((p[0] == 'l') || (p[0] == 'L'));
+	GD_drawing(g)->landscape = p[0] == 'l' || p[0] == 'L';
     else if ((p = agget(g, "landscape")))
 	GD_drawing(g)->landscape = mapbool(p);
 
     p = agget(g, "clusterrank");
     CL_type = maptoken(p, rankname, rankcode);
     p = agget(g, "concentrate");
-    Concentrate = mapbool(p);
+    Concentrate = mapbool(p) ? TRUE : FALSE;
     State = GVBEGIN;
     EdgeLabelsDone = 0;
 
@@ -928,13 +868,13 @@ void do_graph_label(graph_t * sg)
     int pos_ix;
 
     /* it would be nice to allow multiple graph labels in the future */
-    if ((str = agget(sg, "label")) && (*str != '\0')) {
+    if ((str = agget(sg, "label")) && *str != '\0') {
 	char pos_flag;
 	pointf dimen;
 
 	GD_has_labels(sg->root) |= GRAPH_LABEL;
 
-	GD_label(sg) = make_label(sg, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	GD_label(sg) = make_label(sg, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
 	    late_double(sg, agfindgraphattr(sg, "fontsize"),
 			DEFAULT_FONTSIZE, MIN_FONTSIZE),
 	    late_nnstring(sg, agfindgraphattr(sg, "fontname"),
@@ -945,12 +885,12 @@ void do_graph_label(graph_t * sg)
 	/* set label position */
 	pos = agget(sg, "labelloc");
 	if (sg != agroot(sg)) {
-	    if (pos && (pos[0] == 'b'))
+	    if (pos && pos[0] == 'b')
 		pos_flag = LABEL_AT_BOTTOM;
 	    else
 		pos_flag = LABEL_AT_TOP;
 	} else {
-	    if (pos && (pos[0] == 't'))
+	    if (pos && pos[0] == 't')
 		pos_flag = LABEL_AT_TOP;
 	    else
 		pos_flag = LABEL_AT_BOTTOM;
