@@ -17,21 +17,16 @@
 #include <stdbool.h>
 #include <stdlib.h>
 
-#define PINC 300
-
 static int nedges, nboxes; /* total no. of edges and boxes used in routing */
 
 static int routeinit;
 /* static data used across multiple edges */
-static pointf *ps;             /* final spline points */
-static int maxpn;             /* size of ps[] */
 static Ppoint_t *polypoints;  /* vertices of polygon defined by boxes */
 static int polypointn;        /* size of polypoints[] */
 static Pedge_t *edges;        /* polygon edges passed to Proutespline */
 static int edgen;             /* size of edges[] */
 
 static int checkpath(int, boxf*, path*);
-static int mkspacep(int size);
 static void printpath(path * pp);
 #ifdef DEBUG
 static void printboxes(int boxn, boxf* boxes)
@@ -249,8 +244,11 @@ simpleSplineRoute (pointf tp, pointf hp, Ppoly_t poly, int* n_spl_pts,
             return NULL;
     }
 
-    if (mkspacep(spl.pn))
+    pointf *ps = calloc(spl.pn, sizeof(ps[0]));
+    if (ps == NULL) {
+	agerr(AGERR, "cannot allocate ps\n");
 	return NULL;
+    }
     for (i = 0; i < spl.pn; i++) {
         ps[i] = spl.ps[i];
     }
@@ -266,11 +264,6 @@ int
 routesplinesinit()
 {
     if (++routeinit > 1) return 0;
-    if (!(ps = calloc(PINC, sizeof(pointf)))) {
-	agerr(AGERR, "routesplinesinit: cannot allocate ps\n");
-	return 1;
-    }
-    maxpn = PINC;
 #ifdef DEBUG
     if (Show_boxes) {
         for (int i = 0; Show_boxes[i]; i++)
@@ -290,7 +283,6 @@ routesplinesinit()
 void routesplinesterm()
 {
     if (--routeinit > 0) return;
-    free(ps);
     if (Verbose)
 	fprintf(stderr,
 		"routesplines: %d edges, %d boxes %.2f sec\n",
@@ -312,18 +304,18 @@ limitBoxes (boxf* boxes, int boxn, const pointf *pps, int pn, int delta)
 	    sp[1] = pps[splinepi + 1];
 	    sp[2] = pps[splinepi + 2];
 	    sp[3] = pps[splinepi + 3];
-	    sp[0].x = sp[0].x + t * (sp[1].x - sp[0].x);
-	    sp[0].y = sp[0].y + t * (sp[1].y - sp[0].y);
-	    sp[1].x = sp[1].x + t * (sp[2].x - sp[1].x);
-	    sp[1].y = sp[1].y + t * (sp[2].y - sp[1].y);
-	    sp[2].x = sp[2].x + t * (sp[3].x - sp[2].x);
-	    sp[2].y = sp[2].y + t * (sp[3].y - sp[2].y);
- 	    sp[0].x = sp[0].x + t * (sp[1].x - sp[0].x);
-	    sp[0].y = sp[0].y + t * (sp[1].y - sp[0].y);
-	    sp[1].x = sp[1].x + t * (sp[2].x - sp[1].x);
-	    sp[1].y = sp[1].y + t * (sp[2].y - sp[1].y);
-	    sp[0].x = sp[0].x + t * (sp[1].x - sp[0].x);
-	    sp[0].y = sp[0].y + t * (sp[1].y - sp[0].y);
+	    sp[0].x += t * (sp[1].x - sp[0].x);
+	    sp[0].y += t * (sp[1].y - sp[0].y);
+	    sp[1].x += t * (sp[2].x - sp[1].x);
+	    sp[1].y += t * (sp[2].y - sp[1].y);
+	    sp[2].x += t * (sp[3].x - sp[2].x);
+	    sp[2].y += t * (sp[3].y - sp[2].y);
+	    sp[0].x += t * (sp[1].x - sp[0].x);
+	    sp[0].y += t * (sp[1].y - sp[0].y);
+	    sp[1].x += t * (sp[2].x - sp[1].x);
+	    sp[1].y += t * (sp[2].y - sp[1].y);
+	    sp[0].x += t * (sp[1].x - sp[0].x);
+	    sp[0].y += t * (sp[1].y - sp[0].y);
 	    for (bi = 0; bi < boxn; bi++) {
 /* this tested ok on 64bit machines, but on 32bit we need this FUDGE
  *     or graphs/directed/records.gv fails */
@@ -559,8 +551,11 @@ static pointf *_routesplines(path * pp, int *npoints, int polyline)
 	}
 #endif
     }
-    if (mkspacep(spl.pn))
+    pointf *ps = calloc(spl.pn, sizeof(ps[0]));
+    if (ps == NULL) {
+	agerr(AGERR, "cannot allocate ps\n");
 	return NULL;  /* Bailout if no memory left */
+    }
 
     for (bi = 0; bi < boxn; bi++) {
 	boxes[bi].LL.x = INT_MAX;
@@ -784,20 +779,6 @@ static int checkpath(int boxn, boxf* boxes, path* thepath)
     return 0;
 }
 
-static int mkspacep(int size)
-{
-    if (size > maxpn) {
-	int newmax = maxpn + (size / PINC + 1) * PINC;
-	ps = realloc(ps, newmax * sizeof(pointf));
-	if (!ps) {
-	    agerr(AGERR, "cannot re-allocate ps\n");
-	    return 1;
-	}
-	maxpn = newmax;
-    }
-    return 0;
-}
-
 static void printpath(path * pp)
 {
     int bi;
@@ -854,13 +835,18 @@ static void* vec_get(vec* pvec, size_t index)
 
 static void vec_delete(vec* pvec)
 {
-    for (size_t i = 0; i < vec_length(pvec); ++i) {
-      vec_delete(vec_get(pvec, i));
-    }
     free(pvec->_mem);
     free(pvec);
 }
 
+// cycles is assumed to be a vec of vec of nodes.
+static void cycles_delete(vec* cycles) {
+  for (size_t i = 0; i < vec_length(cycles); ++i) {
+    vec_delete(vec_get(cycles, i));
+  }
+  vec_delete(cycles);
+}
+
 static void vec_push_back(vec* pvec, void* data)
 {
     if (pvec->_elems == pvec->_capelems) {
@@ -980,6 +966,7 @@ static void dfs(graph_t *g, node_t* search, vec* visited, node_t* end, vec* cycl
 	}
 }
 
+// Returns a vec of vec of nodes (aka a vector of cycles), which must be freed using cycles_delete.
 static vec* find_all_cycles(graph_t *g)
 {
     node_t *n;
@@ -995,7 +982,7 @@ static vec* find_all_cycles(graph_t *g)
 		dfs(g, n, cycle, n, cycles);
 	}
 	
-	vec_delete(alloced_cycles); //cycles contains copied vecs
+	cycles_delete(alloced_cycles); //cycles contains copied vecs
     return cycles;
 }
 
@@ -1025,17 +1012,7 @@ static vec* find_shortest_cycle_with_edge(vec* cycles, edge_t* edge, size_t min_
 
 static pointf get_cycle_centroid(graph_t *g, edge_t* edge)
 {
-	static vec* cycles = 0;
-	static graph_t* ref_g = 0;
-
-	if (cycles == 0 || ref_g != g) {
-		//free the memory we're using to hold the previous cycles
-		if (cycles != 0) {
-			vec_delete(cycles);
-		}
-		cycles = find_all_cycles(g);
-		ref_g = g;
-	}
+	vec* cycles = find_all_cycles(g);
 
 	//find the center of the shortest cycle containing this edge
 	//cycles of length 2 do their own thing, we want 3 or
@@ -1046,8 +1023,11 @@ static pointf get_cycle_centroid(graph_t *g, edge_t* edge)
 	size_t idx; //edge index
 	node_t *n;
 
-	if (!cycle)
+	if (cycle == NULL) {
+		if (cycles != NULL)
+			cycles_delete(cycles);
 		return get_centroid(g);
+	}
 
 	cycle_len = vec_length(cycle);
 
@@ -1058,6 +1038,9 @@ static pointf get_cycle_centroid(graph_t *g, edge_t* edge)
         cnt++;
 	}
 
+	if (cycles != NULL)
+		cycles_delete(cycles);
+
 	sum.x /= cnt;
     sum.y /= cnt;
     return sum;
@@ -1071,8 +1054,8 @@ static void bend(pointf spl[4], pointf centroid)
 
     midpt.x = (spl[0].x + spl[3].x)/2.0;
     midpt.y = (spl[0].y + spl[3].y)/2.0;
-    dx = (spl[3].x - spl[0].x);
-    dy = (spl[3].y - spl[0].y);
+    dx = spl[3].x - spl[0].x;
+    dy = spl[3].y - spl[0].y;
     dist = hypot(dx, dy);
     r = dist/5.0;
     {
@@ -1092,31 +1075,24 @@ static void bend(pointf spl[4], pointf centroid)
  *
  * FIX: handle ports on boundary?
  */
-#define MAX_EDGE 20
 void 
 makeStraightEdge(graph_t * g, edge_t * e, int et, splineInfo* sinfo)
 {
     edge_t *e0;
-    edge_t** edges;
-    edge_t* elist[MAX_EDGE];
     int i, e_cnt;
 
     e_cnt = 1;
     e0 = e;
     while (e0 != ED_to_virt(e0) && (e0 = ED_to_virt(e0))) e_cnt++;
 
-    if (e_cnt <= MAX_EDGE)
-	edges = elist;
-    else
-	edges = N_NEW(e_cnt,edge_t*);
+    edge_t **edges = N_NEW(e_cnt, edge_t*);
     e0 = e;
     for (i = 0; i < e_cnt; i++) {
 	edges[i] = e0;
 	e0 = ED_to_virt(e0);
     }
     makeStraightEdges (g, edges, e_cnt, et, sinfo);
-    if (e_cnt > MAX_EDGE) free (edges);
-
+    free(edges);
 }
 
 void 
@@ -1125,7 +1101,7 @@ makeStraightEdges(graph_t * g, edge_t** edges, int e_cnt, int et, splineInfo* si
     pointf dumb[4];
     node_t *n;
     node_t *head;
-    bool curved = et == ET_CURVED;
+    bool curved = et == EDGETYPE_CURVED;
     pointf perp;
     pointf del;
     edge_t *e0;
@@ -1133,17 +1109,16 @@ makeStraightEdges(graph_t * g, edge_t** edges, int e_cnt, int et, splineInfo* si
     int i, j, xstep, dx;
     double l_perp;
     pointf dumber[4];
-    pointf p, q;
 
     e = edges[0];
     n = agtail(e);
     head = aghead(e);
-    p = dumb[1] = dumb[0] = add_pointf(ND_coord(n), ED_tail_port(e).p);
-    q = dumb[2] = dumb[3] = add_pointf(ND_coord(head), ED_head_port(e).p);
+    dumb[1] = dumb[0] = add_pointf(ND_coord(n), ED_tail_port(e).p);
+    dumb[2] = dumb[3] = add_pointf(ND_coord(head), ED_head_port(e).p);
     if (e_cnt == 1 || Concentrate) {
 	if (curved) bend(dumb,get_cycle_centroid(g, edges[0]));
 	clip_and_install(e, aghead(e), dumb, 4, sinfo);
-	addEdgeLabels(g, e, p, q);
+	addEdgeLabels(e);
 	return;
     }
 
@@ -1172,19 +1147,15 @@ makeStraightEdges(graph_t * g, edge_t** edges, int e_cnt, int et, splineInfo* si
     for (i = 0; i < e_cnt; i++) {
 	e0 = edges[i];
 	if (aghead(e0) == head) {
-	    p = dumb[0];
-	    q = dumb[3];
 	    for (j = 0; j < 4; j++) {
 		dumber[j] = dumb[j];
 	    }
 	} else {
-	    p = dumb[3];
-	    q = dumb[0];
 	    for (j = 0; j < 4; j++) {
 		dumber[3 - j] = dumb[j];
 	    }
 	}
-	if (et == ET_PLINE) {
+	if (et == EDGETYPE_PLINE) {
 	    Ppoint_t pts[4];
 	    Ppolyline_t spl, line;
 
@@ -1199,7 +1170,7 @@ makeStraightEdges(graph_t * g, edge_t** edges, int e_cnt, int et, splineInfo* si
 	else
 	    clip_and_install(e0, aghead(e0), dumber, 4, sinfo);
 
-	addEdgeLabels(g, e0, p, q);
+	addEdgeLabels(e0);
 	dumb[1].x += del.x;
 	dumb[1].y += del.y;
 	dumb[2].x += del.x;
