@@ -1,14 +1,11 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
- * Copyright (c) 2011 AT&T Intellectual Property 
+ * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -16,16 +13,19 @@
  * an edge, starting from a list of control points.
  */
 
-#include "render.h"
+#include <math.h>
+#include <common/render.h>
+#include <cgraph/unreachable.h>
+#include <stdbool.h>
 
 #ifdef DEBUG
 static int debugleveln(edge_t* e, int i)
 {
-    return (GD_showboxes(agraphof(aghead(e))) == i ||
+    return GD_showboxes(agraphof(aghead(e))) == i ||
 	    GD_showboxes(agraphof(agtail(e))) == i ||
 	    ED_showboxes(e) == i ||
 	    ND_showboxes(aghead(e)) == i ||
-	    ND_showboxes(agtail(e)) == i);
+	    ND_showboxes(agtail(e)) == i;
 }
 
 static void showPoints(pointf ps[], int pn)
@@ -39,7 +39,7 @@ static void showPoints(pointf ps[], int pn)
     Show_boxes[li++] = strdup ("%% self list");
     Show_boxes[li++] = strdup ("dbgstart");
     for (bi = 0; bi < pn; bi++) {
-	sprintf(buf, "%.5g %.5g point", ps[bi].x, ps[bi].y);
+	snprintf(buf, sizeof(buf), "%.5g %.5g point", ps[bi].x, ps[bi].y);
 	Show_boxes[li++] = strdup (buf);
     }
     Show_boxes[li++] = strdup ("grestore");
@@ -62,12 +62,13 @@ arrow_clip(edge_t * fe, node_t * hn,
 	   bezier * spl, splineInfo * info)
 {
     edge_t *e;
-    int i, j, sflag, eflag;
+    int i, sflag, eflag;
+    bool j;
 
     for (e = fe; ED_to_orig(e); e = ED_to_orig(e));
 
     if (info->ignoreSwap)
-	j = 0;
+	j = false;
     else
 	j = info->swapEnds(e);
     arrow_flags(e, &sflag, &eflag);
@@ -87,11 +88,9 @@ arrow_clip(edge_t * fe, node_t * hn,
     }
     else {
 	if (sflag)
-	    *startp =
-		arrowStartClip(e, ps, *startp, *endp, spl, sflag);
+	    *startp = arrowStartClip(e, ps, *startp, *endp, spl, sflag);
 	if (eflag)
-	    *endp =
-		arrowEndClip(e, ps, *startp, *endp, spl, eflag);
+	    *endp = arrowEndClip(e, ps, *startp, *endp, spl, eflag);
     }
 }
 
@@ -99,17 +98,17 @@ arrow_clip(edge_t * fe, node_t * hn,
  * Clip bezier to shape using binary search.
  * The details of the shape are passed in the inside_context;
  * The function providing the inside test is passed as a parameter.
- * left_inside specifies that sp[0] is inside the node, 
+ * left_inside specifies that sp[0] is inside the node,
  * else sp[3] is taken as inside.
  * The points p are in node coordinates.
  */
 void bezier_clip(inside_t * inside_context,
-		 boolean(*inside) (inside_t * inside_context, pointf p),
-		 pointf * sp, boolean left_inside)
+		 bool(*inside) (inside_t * inside_context, pointf p),
+		 pointf * sp, bool left_inside)
 {
     pointf seg[4], best[4], pt, opt, *left, *right;
     double low, high, t, *idir, *odir;
-    boolean found;
+    bool found;
     int i;
 
     if (left_inside) {
@@ -125,7 +124,7 @@ void bezier_clip(inside_t * inside_context,
 	idir = &high;
 	odir = &low;
     }
-    found = FALSE;
+    found = false;
     low = 0.0;
     high = 1.0;
     do {
@@ -137,10 +136,10 @@ void bezier_clip(inside_t * inside_context,
 	} else {
 	    for (i = 0; i < 4; i++)
 		best[i] = seg[i];
-	    found = TRUE;
+	    found = true;
 	    *odir = t;
 	}
-    } while (ABS(opt.x - pt.x) > .5 || ABS(opt.y - pt.y) > .5);
+    } while (fabs(opt.x - pt.x) > .5 || fabs(opt.y - pt.y) > .5);
     if (found)
 	for (i = 0; i < 4; i++)
 	    sp[i] = best[i];
@@ -158,7 +157,7 @@ void bezier_clip(inside_t * inside_context,
  */
 static void
 shape_clip0(inside_t * inside_context, node_t * n, pointf curve[4],
-	    boolean left_inside)
+	    bool left_inside)
 {
     int i;
     double save_real_size;
@@ -170,8 +169,7 @@ shape_clip0(inside_t * inside_context, node_t * n, pointf curve[4],
 	c[i].y = curve[i].y - ND_coord(n).y;
     }
 
-    bezier_clip(inside_context, ND_shape(n)->fns->insidefn, c,
-		left_inside);
+    bezier_clip(inside_context, ND_shape(n)->fns->insidefn, c, left_inside);
 
     for (i = 0; i < 4; i++) {
 	curve[i].x = c[i].x + ND_coord(n).x;
@@ -182,7 +180,7 @@ shape_clip0(inside_t * inside_context, node_t * n, pointf curve[4],
 
 /* shape_clip:
  * Clip Bezier to node shape
- * Uses curve[0] to determine which which side is inside the node. 
+ * Uses curve[0] to determine which which side is inside the node.
  * NOTE: This test is bad. It is possible for previous call to
  * shape_clip to produce a Bezier with curve[0] moved to the boundary
  * for which insidefn(curve[0]) is true. Thus, if the new Bezier is
@@ -195,7 +193,7 @@ shape_clip0(inside_t * inside_context, node_t * n, pointf curve[4],
 void shape_clip(node_t * n, pointf curve[4])
 {
     double save_real_size;
-    boolean left_inside;
+    bool left_inside;
     pointf c;
     inside_t inside_context;
 
@@ -257,7 +255,7 @@ clip_and_install(edge_t * fe, node_t * hn, pointf * ps, int pn,
     for (orig = fe; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
 
     /* may be a reversed flat edge */
-    if (!info->ignoreSwap && (ND_rank(tn) == ND_rank(hn)) && (ND_order(tn) > ND_order(hn))) {
+    if (!info->ignoreSwap && ND_rank(tn) == ND_rank(hn) && ND_order(tn) > ND_order(hn)) {
 	node_t *tmp;
 	tmp = hn;
 	hn = tn;
@@ -283,10 +281,10 @@ clip_and_install(edge_t * fe, node_t * hn, pointf * ps, int pn,
 	for (start = 0; start < pn - 4; start += 3) {
 	    p2.x = ps[start + 3].x - ND_coord(tn).x;
 	    p2.y = ps[start + 3].y - ND_coord(tn).y;
-	    if (ND_shape(tn)->fns->insidefn(&inside_context, p2) == FALSE)
+	    if (!ND_shape(tn)->fns->insidefn(&inside_context, p2))
 		break;
 	}
-	shape_clip0(&inside_context, tn, &ps[start], TRUE);
+	shape_clip0(&inside_context, tn, &ps[start], true);
     } else
 	start = 0;
     if(clipHead && ND_shape(hn) && ND_shape(hn)->fns->insidefn) {
@@ -295,19 +293,19 @@ clip_and_install(edge_t * fe, node_t * hn, pointf * ps, int pn,
 	for (end = pn - 4; end > 0; end -= 3) {
 	    p2.x = ps[end].x - ND_coord(hn).x;
 	    p2.y = ps[end].y - ND_coord(hn).y;
-	    if (ND_shape(hn)->fns->insidefn(&inside_context, p2) == FALSE)
+	    if (!ND_shape(hn)->fns->insidefn(&inside_context, p2))
 		break;
 	}
-	shape_clip0(&inside_context, hn, &ps[end], FALSE);
+	shape_clip0(&inside_context, hn, &ps[end], false);
     } else
 	end = pn - 4;
-    for (; start < pn - 4; start += 3) 
+    for (; start < pn - 4; start += 3)
 	if (! APPROXEQPT(ps[start], ps[start + 3], MILLIPOINT))
 	    break;
     for (; end > 0; end -= 3)
 	if (! APPROXEQPT(ps[end], ps[end + 3], MILLIPOINT))
 	    break;
-   arrow_clip(fe, hn, ps, &start, &end, newspl, info);
+    arrow_clip(fe, hn, ps, &start, &end, newspl, info);
     for (i = start; i < end + 4; ) {
 	pointf cp[4];
 	newspl->list[i - start] = ps[i];
@@ -327,7 +325,7 @@ clip_and_install(edge_t * fe, node_t * hn, pointf * ps, int pn,
     newspl->size = end - start + 4;
 }
 
-static double 
+static double
 conc_slope(node_t* n)
 {
     double s_in, s_out, m_in, m_out;
@@ -343,10 +341,10 @@ conc_slope(node_t* n)
     p.x = ND_coord(n).x - (s_in / cnt_in);
     p.y = ND_coord(n).y - ND_coord(agtail(ND_in(n).list[0])).y;
     m_in = atan2(p.y, p.x);
-    p.x = (s_out / cnt_out) - ND_coord(n).x;
+    p.x = s_out / cnt_out - ND_coord(n).x;
     p.y = ND_coord(aghead(ND_out(n).list[0])).y - ND_coord(n).y;
     m_out = atan2(p.y, p.x);
-    return ((m_in + m_out) / 2.0);
+    return (m_in + m_out) / 2.0;
 }
 
 void add_box(path * P, boxf b)
@@ -357,13 +355,13 @@ void add_box(path * P, boxf b)
 
 /* beginpath:
  * Set up boxes near the tail node.
- * For regular nodes, the result should be a list of contiguous rectangles 
+ * For regular nodes, the result should be a list of contiguous rectangles
  * such that the last one has the smallest LL.y and its LL.y is above
  * the bottom of the rank (rank.ht1).
- * 
+ *
  * For flat edges, we assume endp->sidemask has been set. For regular
  * edges, we set this, but it doesn't appear to be needed any more.
- * 
+ *
  * In many cases, we tweak the x or y coordinate of P->start.p by 1.
  * This is because of a problem in the path routing code. If the starting
  * point actually lies on the polygon, in some cases, the router gets
@@ -390,7 +388,7 @@ void add_box(path * P, boxf b)
 #define HT2(n) (ND_ht(n)/2)
 
 void
-beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
+beginpath(path * P, edge_t * e, int et, pathend_t * endp, bool merge)
 {
     int side, mask;
     node_t *n;
@@ -408,18 +406,18 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
     if (merge) {
 	/*P->start.theta = - M_PI / 2; */
 	P->start.theta = conc_slope(agtail(e));
-	P->start.constrained = TRUE;
+	P->start.constrained = true;
     } else {
 	if (ED_tail_port(e).constrained) {
 	    P->start.theta = ED_tail_port(e).theta;
-	    P->start.constrained = TRUE;
+	    P->start.constrained = true;
 	} else
-	    P->start.constrained = FALSE;
+	    P->start.constrained = false;
     }
     P->nbox = 0;
     P->data = (void *) e;
     endp->np = P->start.p;
-    if ((et == REGULAREDGE) && (ND_node_type(n) == NORMAL) && ((side = ED_tail_port(e).side))) {
+    if (et == REGULAREDGE && ND_node_type(n) == NORMAL && (side = ED_tail_port(e).side)) {
 	edge_t* orig;
 	boxf b0, b = endp->nb;
 	if (side & TOP) {
@@ -433,7 +431,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.UR.x = ND_coord(n).x - ND_lw(n) - (FUDGE-2);
 		b.UR.y = b0.LL.y;
 		b.LL.y = ND_coord(n).y - HT2(n);
-		b.LL.x -= 1;
+		--b.LL.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
 	    }
@@ -446,11 +444,11 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.LL.x = ND_coord(n).x + ND_rw(n) + (FUDGE-2);
 		b.UR.y = b0.LL.y;
 		b.LL.y = ND_coord(n).y - HT2(n);
-		b.UR.x += 1;
+		++b.UR.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
-	    } 
-	    P->start.p.y += 1;
+	    }
+	    ++P->start.p.y;
 	    endp->boxn = 2;
 	}
 	else if (side & BOTTOM) {
@@ -458,7 +456,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.UR.y = MAX(b.UR.y,P->start.p.y);
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.y -= 1;
+	    --P->start.p.y;
 	}
 	else if (side & LEFT) {
 	    endp->sidemask = LEFT;
@@ -467,7 +465,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.UR.y = P->start.p.y;
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.x -= 1;
+	    --P->start.p.x;
 	}
 	else {
 	    endp->sidemask = RIGHT;
@@ -476,23 +474,23 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.UR.y = P->start.p.y;
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.x += 1;
+	    ++P->start.p.x;
 	}
 	for (orig = e; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
 	if (n == agtail(orig))
-	    ED_tail_port(orig).clip = FALSE;
+	    ED_tail_port(orig).clip = false;
 	else
-	    ED_head_port(orig).clip = FALSE;
+	    ED_head_port(orig).clip = false;
 	return;
     }
-    if ((et == FLATEDGE) && ((side = ED_tail_port(e).side))) {
+    if (et == FLATEDGE && (side = ED_tail_port(e).side)) {
 	boxf b0, b = endp->nb;
 	edge_t* orig;
 	if (side & TOP) {
 	    b.LL.y = MIN(b.LL.y,P->start.p.y);
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.y += 1;
+	    ++P->start.p.y;
 	}
 	else if (side & BOTTOM) {
 	    if (endp->sidemask == TOP) {
@@ -503,7 +501,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.LL.x = ND_coord(n).x + ND_rw(n) + (FUDGE-2);
 		b.LL.y = b0.UR.y;
 		b.UR.y = ND_coord(n).y + HT2(n);
-		b.UR.x += 1;
+		++b.UR.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
 		endp->boxn = 2;
@@ -513,7 +511,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		endp->boxes[0] = b;
 		endp->boxn = 1;
 	    }
-	    P->start.p.y -= 1;
+	    --P->start.p.y;
 	}
 	else if (side & LEFT) {
 	    b.UR.x = P->start.p.x+1;
@@ -527,7 +525,7 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    }
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.x -= 1;
+	    --P->start.p.x;
 	}
 	else {
 	    b.LL.x = P->start.p.x;
@@ -541,13 +539,13 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    }
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->start.p.x += 1;
+	    ++P->start.p.x;
 	}
 	for (orig = e; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
 	if (n == agtail(orig))
-	    ED_tail_port(orig).clip = FALSE;
+	    ED_tail_port(orig).clip = false;
 	else
-	    ED_head_port(orig).clip = FALSE;
+	    ED_head_port(orig).clip = false;
 	endp->sidemask = side;
 	return;
     }
@@ -579,13 +577,13 @@ beginpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	case REGULAREDGE:
 	    endp->boxes[0].UR.y = P->start.p.y;
 	    endp->sidemask = BOTTOM;
-	    P->start.p.y -= 1;
+	    --P->start.p.y;
 	    break;
-	}    
-    }    
+	}
+    }
 }
 
-void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
+void endpath(path * P, edge_t * e, int et, pathend_t * endp, bool merge)
 {
     int side, mask;
     node_t *n;
@@ -593,7 +591,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 
     n = aghead(e);
 
-    if (ED_head_port(e).dyna) 
+    if (ED_head_port(e).dyna)
 	ED_head_port(e) = resolvePort(aghead(e), agtail(e), &ED_head_port(e));
     if (ND_shape(n))
 	pboxfn = ND_shape(n)->fns->pboxfn;
@@ -604,16 +602,16 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	/*P->end.theta = M_PI / 2; */
 	P->end.theta = conc_slope(aghead(e)) + M_PI;
 	assert(P->end.theta < 2 * M_PI);
-	P->end.constrained = TRUE;
+	P->end.constrained = true;
     } else {
 	if (ED_head_port(e).constrained) {
 	    P->end.theta = ED_head_port(e).theta;
-	    P->end.constrained = TRUE;
+	    P->end.constrained = true;
 	} else
-	    P->end.constrained = FALSE;
+	    P->end.constrained = false;
     }
     endp->np = P->end.p;
-    if ((et == REGULAREDGE) && (ND_node_type(n) == NORMAL) && ((side = ED_head_port(e).side))) {
+    if (et == REGULAREDGE && ND_node_type(n) == NORMAL && (side = ED_head_port(e).side)) {
 	edge_t* orig;
 	boxf b0, b = endp->nb;
 	if (side & TOP) {
@@ -621,7 +619,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.LL.y = MIN(b.LL.y,P->end.p.y);
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.y += 1;
+	    ++P->end.p.y;
 	}
 	else if (side & BOTTOM) {
 	    endp->sidemask = BOTTOM;
@@ -634,7 +632,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.UR.x = ND_coord(n).x - ND_lw(n) - (FUDGE-2);
 		b.LL.y = b0.UR.y;
 		b.UR.y = ND_coord(n).y + HT2(n);
-		b.LL.x -= 1;
+		--b.LL.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
 	    }
@@ -647,12 +645,12 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.LL.x = ND_coord(n).x + ND_rw(n) + (FUDGE-2);
 		b.LL.y = b0.UR.y;
 		b.UR.y = ND_coord(n).y + HT2(n);
-		b.UR.x += 1;
+		++b.UR.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
-	    } 
+	    }
 	    endp->boxn = 2;
-	    P->end.p.y -= 1;
+	    --P->end.p.y;
 	}
 	else if (side & LEFT) {
 	    endp->sidemask = LEFT;
@@ -661,7 +659,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.LL.y = P->end.p.y;
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.x -= 1;
+	    --P->end.p.x;
 	}
 	else {
 	    endp->sidemask = RIGHT;
@@ -670,25 +668,25 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    b.LL.y = P->end.p.y;
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.x += 1;
+	    ++P->end.p.x;
 	}
 	for (orig = e; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
 	if (n == aghead(orig))
-	    ED_head_port(orig).clip = FALSE;
+	    ED_head_port(orig).clip = false;
 	else
-	    ED_tail_port(orig).clip = FALSE;
+	    ED_tail_port(orig).clip = false;
 	endp->sidemask = side;
 	return;
     }
 
-    if ((et == FLATEDGE) && ((side = ED_head_port(e).side))) {
+    if (et == FLATEDGE && (side = ED_head_port(e).side)) {
 	boxf b0, b = endp->nb;
 	edge_t* orig;
 	if (side & TOP) {
 	    b.LL.y = MIN(b.LL.y,P->end.p.y);
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.y += 1;
+	    ++P->end.p.y;
 	}
 	else if (side & BOTTOM) {
 	    if (endp->sidemask == TOP) {
@@ -699,7 +697,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		b.UR.x = ND_coord(n).x - ND_lw(n) - 2;
 		b.LL.y = b0.UR.y;
 		b.UR.y = ND_coord(n).y + HT2(n);
-		b.LL.x -= 1;
+		--b.LL.x;
 		endp->boxes[0] = b0;
 		endp->boxes[1] = b;
 		endp->boxn = 2;
@@ -709,7 +707,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 		endp->boxes[0] = b;
 		endp->boxn = 1;
 	    }
-	    P->end.p.y -= 1;
+	    --P->end.p.y;
 	}
 	else if (side & LEFT) {
 	    b.UR.x = P->end.p.x+1;
@@ -723,7 +721,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    }
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.x -= 1;
+	    --P->end.p.x;
 	}
 	else {
 	    b.LL.x = P->end.p.x-1;
@@ -737,13 +735,13 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	    }
 	    endp->boxes[0] = b;
 	    endp->boxn = 1;
-	    P->end.p.x += 1;
+	    ++P->end.p.x;
 	}
 	for (orig = e; ED_edge_type(orig) != NORMAL; orig = ED_to_orig(orig));
 	if (n == aghead(orig))
-	    ED_head_port(orig).clip = FALSE;
+	    ED_head_port(orig).clip = false;
 	else
-	    ED_tail_port(orig).clip = FALSE;
+	    ED_tail_port(orig).clip = false;
 	endp->sidemask = side;
 	return;
     }
@@ -759,8 +757,8 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 
 	switch (et) {
 	case SELFEDGE:
-	    /* offset of -1 is symmetric w.r.t. beginpath() 
-	     * FIXME: is any of this right?  what if self-edge 
+	    /* offset of -1 is symmetric w.r.t. beginpath()
+	     * FIXME: is any of this right?  what if self-edge
 	     * doesn't connect from BOTTOM to TOP??? */
 	    assert(0);  /* at present, we don't use endpath for selfedges */
 	    endp->boxes[0].LL.y = P->end.p.y + 1;
@@ -775,7 +773,7 @@ void endpath(path * P, edge_t * e, int et, pathend_t * endp, boolean merge)
 	case REGULAREDGE:
 	    endp->boxes[0].LL.y = P->end.p.y;
 	    endp->sidemask = TOP;
-	    P->end.p.y += 1;
+	    ++P->end.p.y;
 	    break;
 	}
     }
@@ -819,22 +817,20 @@ else
 
 
 static void selfBottom (edge_t* edges[], int ind, int cnt,
-	double sizex, double stepy, splineInfo* sinfo) 
+	double sizex, double stepy, splineInfo* sinfo)
 {
     pointf tp, hp, np;
     node_t *n;
     edge_t *e;
     int i, sgn, point_pair;
-    double hy, ty, stepx, dx, dy, width, height; 
+    double hy, ty, stepx, dx, dy, height;
     pointf points[1000];
     int pointn;
 
     e = edges[ind];
     n = agtail(e);
 
-    stepx = (sizex / 2.) / cnt;
-    stepx = MAX(stepx,2.);
-    pointn = 0;
+    stepx = fmax(sizex / 2.0 / cnt, 2.0);
     np = ND_coord(n);
     tp = ED_tail_port(e).p;
     tp.x += np.x;
@@ -844,8 +840,9 @@ static void selfBottom (edge_t* edges[], int ind, int cnt,
     hp.y += np.y;
     if (tp.x >= hp.x) sgn = 1;
     else sgn = -1;
-    dy = ND_ht(n)/2., dx = 0.;
-    // certain adjustments are required for some point_pairs in order to improve the 
+    dy = ND_ht(n) / 2.0;
+    dx = 0.0;
+    // certain adjustments are required for some point_pairs in order to improve the
     // display of the edge path between them
     point_pair = convert_sides_to_points(ED_tail_port(e).side,ED_head_port(e).side);
     switch(point_pair){
@@ -854,11 +851,14 @@ static void selfBottom (edge_t* edges[], int ind, int cnt,
       default:
 		break;
     }
-    ty = MIN(dy, 3*(tp.y + dy - np.y));
-    hy = MIN(dy, 3*(hp.y + dy - np.y));
+    ty = fmin(dy, 3 * (tp.y + dy - np.y));
+    hy = fmin(dy, 3 * (hp.y + dy - np.y));
     for (i = 0; i < cnt; i++) {
         e = edges[ind++];
-        dy += stepy, ty += stepy, hy += stepy, dx += sgn*stepx;
+        dy += stepy;
+        ty += stepy;
+        hy += stepy;
+        dx += sgn * stepx;
         pointn = 0;
         points[pointn++] = tp;
         points[pointn++] = pointfof(tp.x + dx, tp.y - ty / 3);
@@ -869,10 +869,8 @@ static void selfBottom (edge_t* edges[], int ind, int cnt,
         points[pointn++] = hp;
         if (ED_label(e)) {
 	if (GD_flip(agraphof(agtail(e)))) {
-    	    width = ED_label(e)->dimen.y;
     	    height = ED_label(e)->dimen.x;
     	} else {
-    	    width = ED_label(e)->dimen.x;
     	    height = ED_label(e)->dimen.y;
     	}
     	ED_label(e)->pos.y = ND_coord(n).y - dy - height / 2.0;
@@ -892,10 +890,10 @@ static void selfBottom (edge_t* edges[], int ind, int cnt,
 
 static void
 selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
-           splineInfo* sinfo) 
+           splineInfo* sinfo)
 {
     int i, sgn, point_pair;
-    double hy, ty,  stepx, dx, dy, width, height; 
+    double hy, ty,  stepx, dx, dy, height;
     pointf tp, hp, np;
     node_t *n;
     edge_t *e;
@@ -905,9 +903,7 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
     e = edges[ind];
     n = agtail(e);
 
-    stepx = (sizex / 2.) / cnt;
-    stepx = MAX(stepx, 2.);
-    pointn = 0;
+    stepx = fmax(sizex / 2.0 / cnt, 2.0);
     np = ND_coord(n);
     tp = ED_tail_port(e).p;
     tp.x += np.x;
@@ -918,7 +914,7 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
     if (tp.x >= hp.x) sgn = 1;
     else sgn = -1;
     dy = ND_ht(n)/2., dx = 0.;
-    // certain adjustments are required for some point_pairs in order to improve the 
+    // certain adjustments are required for some point_pairs in order to improve the
     // display of the edge path between them
     point_pair = convert_sides_to_points(ED_tail_port(e).side,ED_head_port(e).side);
     switch(point_pair){
@@ -942,7 +938,7 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
 	case 51:
 	case 57:
 	case 58:
-		dx = sgn*((((ND_lw(n)-(np.x-tp.x)) + (ND_rw(n)-(hp.x-np.x)))/3.));
+		dx = sgn * ((ND_lw(n) - (np.x - tp.x) + (ND_rw(n) - (hp.x - np.x))) / 3.0);
 		break;
 	case 73:
  		dx = sgn*(ND_lw(n)-(np.x-tp.x) + stepx);
@@ -951,21 +947,28 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
 		dx = sgn*(ND_lw(n)-(np.x-tp.x));
 		break;
 	case 84:
-		dx = sgn*((((ND_lw(n)-(np.x-tp.x)) + (ND_rw(n)-(hp.x-np.x)))/2.) + stepx);
-		break;
+          dx = sgn *
+               ((ND_lw(n) - (np.x - tp.x) + (ND_rw(n) - (hp.x - np.x))) / 2.0 +
+                stepx);
+          break;
 	case 74:
 	case 75:
 	case 85:
-		dx = sgn*((((ND_lw(n)-(np.x-tp.x)) + (ND_rw(n)-(hp.x-np.x)))/2.) + 2*stepx);
-		break;
+          dx = sgn *
+               ((ND_lw(n) - (np.x - tp.x) + (ND_rw(n) - (hp.x - np.x))) / 2.0 +
+                2 * stepx);
+          break;
 	default:
 		break;
     }
-    ty = MIN(dy, 3*(np.y + dy - tp.y));
-    hy = MIN(dy, 3*(np.y + dy - hp.y));
+    ty = fmin(dy, 3 * (np.y + dy - tp.y));
+    hy = fmin(dy, 3 * (np.y + dy - hp.y));
     for (i = 0; i < cnt; i++) {
         e = edges[ind++];
-        dy += stepy, ty += stepy, hy += stepy, dx += sgn*stepx;
+        dy += stepy;
+        ty += stepy;
+        hy += stepy;
+        dx += sgn * stepx;
         pointn = 0;
         points[pointn++] = tp;
         points[pointn++] = pointfof(tp.x + dx, tp.y + ty / 3);
@@ -976,10 +979,8 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
         points[pointn++] = hp;
         if (ED_label(e)) {
 	    if (GD_flip(agraphof(agtail(e)))) {
-		width = ED_label(e)->dimen.y;
 		height = ED_label(e)->dimen.x;
 	    } else {
-		width = ED_label(e)->dimen.x;
 		height = ED_label(e)->dimen.y;
 	    }
 	    ED_label(e)->pos.y = ND_coord(n).y + dy + height / 2.0;
@@ -999,10 +1000,10 @@ selfTop (edge_t* edges[], int ind, int cnt, double sizex, double stepy,
 
 static void
 selfRight (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
-           splineInfo* sinfo) 
+           splineInfo* sinfo)
 {
     int i, sgn, point_pair;
-    double hx, tx, stepy, dx, dy, width, height; 
+    double hx, tx, stepy, dx, dy, width;
     pointf tp, hp, np;
     node_t *n;
     edge_t *e;
@@ -1012,9 +1013,7 @@ selfRight (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
     e = edges[ind];
     n = agtail(e);
 
-    stepy = (sizey / 2.) / cnt;
-    stepy = MAX(stepy, 2.);
-    pointn = 0;
+    stepy = fmax(sizey / 2.0 / cnt, 2.0);
     np = ND_coord(n);
     tp = ED_tail_port(e).p;
     tp.x += np.x;
@@ -1025,22 +1024,25 @@ selfRight (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
     if (tp.y >= hp.y) sgn = 1;
     else sgn = -1;
     dx = ND_rw(n), dy = 0;
-    // certain adjustments are required for some point_pairs in order to improve the 
+    // certain adjustments are required for some point_pairs in order to improve the
     // display of the edge path between them
     point_pair = convert_sides_to_points(ED_tail_port(e).side,ED_head_port(e).side);
     switch(point_pair){
-      case 32: 
+      case 32:
       case 65:	if(tp.y == hp.y)
 		  sgn = -sgn;
 		break;
       default:
 		break;
     }
-    tx = MIN(dx, 3*(np.x + dx - tp.x));
-    hx = MIN(dx, 3*(np.x + dx - hp.x));
+    tx = fmin(dx, 3 * (np.x + dx - tp.x));
+    hx = fmin(dx, 3 * (np.x + dx - hp.x));
     for (i = 0; i < cnt; i++) {
         e = edges[ind++];
-        dx += stepx, tx += stepx, hx += stepx, dy += sgn*stepy;
+        dx += stepx;
+        tx += stepx;
+        hx += stepx;
+        dy += sgn * stepy;
         pointn = 0;
         points[pointn++] = tp;
         points[pointn++] = pointfof(tp.x + tx / 3, tp.y + dy);
@@ -1052,10 +1054,8 @@ selfRight (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
         if (ED_label(e)) {
 	    if (GD_flip(agraphof(agtail(e)))) {
 		width = ED_label(e)->dimen.y;
-		height = ED_label(e)->dimen.x;
 	    } else {
 		width = ED_label(e)->dimen.x;
-		height = ED_label(e)->dimen.y;
 	    }
 	    ED_label(e)->pos.x = ND_coord(n).x + dx + width / 2.0;
 	    ED_label(e)->pos.y = ND_coord(n).y;
@@ -1074,10 +1074,10 @@ selfRight (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
 
 static void
 selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
-          splineInfo* sinfo) 
+          splineInfo* sinfo)
 {
     int i, sgn,point_pair;
-    double hx, tx, stepy, dx, dy, width, height; 
+    double hx, tx, stepy, dx, dy, width;
     pointf tp, hp, np;
     node_t *n;
     edge_t *e;
@@ -1087,9 +1087,7 @@ selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
     e = edges[ind];
     n = agtail(e);
 
-    stepy = (sizey / 2.) / cnt;
-    stepy = MAX(stepy,2.);
-    pointn = 0;
+    stepy = fmax(sizey / 2.0 / cnt, 2.0);
     np = ND_coord(n);
     tp = ED_tail_port(e).p;
     tp.x += np.x;
@@ -1097,12 +1095,12 @@ selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
     hp = ED_head_port(e).p;
     hp.x += np.x;
     hp.y += np.y;
-    
-    
+
+
     if (tp.y >= hp.y) sgn = 1;
     else sgn = -1;
     dx = ND_lw(n), dy = 0.;
-    // certain adjustments are required for some point_pairs in order to improve the 
+    // certain adjustments are required for some point_pairs in order to improve the
     // display of the edge path between them
     point_pair = convert_sides_to_points(ED_tail_port(e).side,ED_head_port(e).side);
     switch(point_pair){
@@ -1114,11 +1112,14 @@ selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
       default:
 		break;
     }
-    tx = MIN(dx, 3*(tp.x + dx - np.x));
-    hx = MIN(dx, 3*(hp.x + dx - np.x));
+    tx = fmin(dx, 3 * (tp.x + dx - np.x));
+    hx = fmin(dx, 3 * (hp.x + dx - np.x));
     for (i = 0; i < cnt; i++) {
         e = edges[ind++];
-        dx += stepx, tx += stepx, hx += stepx, dy += sgn*stepy;
+        dx += stepx;
+        tx += stepx;
+        hx += stepx;
+        dy += sgn * stepy;
         pointn = 0;
         points[pointn++] = tp;
         points[pointn++] = pointfof(tp.x - tx / 3, tp.y + dy);
@@ -1126,15 +1127,13 @@ selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
         points[pointn++] = pointfof(np.x - dx, (tp.y+hp.y)/2);
         points[pointn++] = pointfof(np.x - dx, hp.y - dy);
         points[pointn++] = pointfof(hp.x - hx / 3, hp.y - dy);
-      
+
         points[pointn++] = hp;
         if (ED_label(e)) {
     	if (GD_flip(agraphof(agtail(e)))) {
     	    width = ED_label(e)->dimen.y;
-    	    height = ED_label(e)->dimen.x;
     	} else {
     	    width = ED_label(e)->dimen.x;
-    	    height = ED_label(e)->dimen.y;
     	}
     	ED_label(e)->pos.x = ND_coord(n).x - dx - width / 2.0;
     	ED_label(e)->pos.y = ND_coord(n).y;
@@ -1159,18 +1158,16 @@ selfLeft (edge_t* edges[], int ind, int cnt, double stepx, double sizey,
  * so using the constant SELF_EDGE_SIZE is going to be wrong.
  * Fortunately, the default nodesep is the same as SELF_EDGE_SIZE.
  */
-int
-selfRightSpace (edge_t* e)
-{
-    int sw;
+double selfRightSpace(edge_t *e) {
+    double sw;
     double label_width;
     textlabel_t* l = ED_label(e);
 
-    if (((!ED_tail_port(e).defined) && (!ED_head_port(e).defined)) ||
-        (!(ED_tail_port(e).side & LEFT) && 
+    if ((!ED_tail_port(e).defined && !ED_head_port(e).defined) ||
+        (!(ED_tail_port(e).side & LEFT) &&
          !(ED_head_port(e).side & LEFT) &&
-          ((ED_tail_port(e).side != ED_head_port(e).side) || 
-          (!(ED_tail_port(e).side & (TOP|BOTTOM)))))) {
+          (ED_tail_port(e).side != ED_head_port(e).side ||
+          !(ED_tail_port(e).side & (TOP|BOTTOM))))) {
 	sw = SELF_EDGE_SIZE;
 	if (l) {
 	    label_width = GD_flip(agraphof(aghead(e))) ? l->dimen.y : l->dimen.x;
@@ -1188,7 +1185,7 @@ selfRightSpace (edge_t* e)
  * Perhaps for self-edges, the label should be centered.
  */
 void
-makeSelfEdge(path * P, edge_t * edges[], int ind, int cnt, double sizex,
+makeSelfEdge(edge_t * edges[], int ind, int cnt, double sizex,
 	     double sizey, splineInfo * sinfo)
 {
     edge_t *e;
@@ -1196,15 +1193,15 @@ makeSelfEdge(path * P, edge_t * edges[], int ind, int cnt, double sizex,
     e = edges[ind];
 
     /* self edge without ports or
-     * self edge with all ports inside, on the right, or at most 1 on top 
-     * and at most 1 on bottom 
+     * self edge with all ports inside, on the right, or at most 1 on top
+     * and at most 1 on bottom
      */
-    
-    if (((!ED_tail_port(e).defined) && (!ED_head_port(e).defined)) ||
-        (!(ED_tail_port(e).side & LEFT) && 
+
+    if ((!ED_tail_port(e).defined && !ED_head_port(e).defined) ||
+        (!(ED_tail_port(e).side & LEFT) &&
          !(ED_head_port(e).side & LEFT) &&
-          ((ED_tail_port(e).side != ED_head_port(e).side) || 
-          (!(ED_tail_port(e).side & (TOP|BOTTOM)))))) {
+          (ED_tail_port(e).side != ED_head_port(e).side ||
+          !(ED_tail_port(e).side & (TOP|BOTTOM))))) {
 	selfRight(edges, ind, cnt, sizex, sizey, sinfo);
     }
 
@@ -1242,11 +1239,11 @@ void makePortLabels(edge_t * e)
     if (!E_labelangle && !E_labeldistance) return;
 
     if (ED_head_label(e) && !ED_head_label(e)->set) {
-	if (place_portlabel(e, TRUE))
+	if (place_portlabel(e, true))
 	    updateBB(agraphof(agtail(e)), ED_head_label(e));
     }
     if (ED_tail_label(e) && !ED_tail_label(e)->set) {
-	if (place_portlabel(e, FALSE))
+	if (place_portlabel(e, false))
 	    updateBB(agraphof(agtail(e)), ED_tail_label(e));
     }
 }
@@ -1305,16 +1302,15 @@ polylineMidpoint (splines* spl, pointf* pp, pointf* pq)
 	    if (d >= dist) {
 		*pp = pf;
 		*pq = qf;
-		mf.x = ((qf.x*dist) + (pf.x*(d-dist)))/d; 
-		mf.y = ((qf.y*dist) + (pf.y*(d-dist)))/d; 
+		mf.x = (qf.x * dist + pf.x * (d - dist)) / d;
+		mf.y = (qf.y * dist + pf.y * (d - dist)) / d;
 		return mf;
 	    }
 	    else
 		dist -= d;
 	}
     }
-    assert (FALSE);   /* should never get here */
-    return mf;
+    UNREACHABLE();
 }
 
 pointf
@@ -1327,12 +1323,12 @@ edgeMidpoint (graph_t* g, edge_t * e)
     if (APPROXEQPT(p, q, MILLIPOINT)) { /* degenerate spline */
 	spf = p;
     }
-    else if ((et == ET_SPLINE) || (et == ET_CURVED)) {
+    else if (et == EDGETYPE_SPLINE || et == EDGETYPE_CURVED) {
 	d.x = (q.x + p.x) / 2.;
 	d.y = (p.y + q.y) / 2.;
 	spf = dotneato_closest(ED_spl(e), d);
     }
-    else {   /* ET_PLINE, ET_ORTHO or ET_LINE */
+    else {   /* EDGETYPE_PLINE, EDGETYPE_ORTHO or EDGETYPE_LINE */
 	spf = polylineMidpoint (ED_spl(e), &p, &q);
     }
 
@@ -1343,73 +1339,11 @@ edgeMidpoint (graph_t* g, edge_t * e)
 #define MAXLABELWD  (POINTS_PER_INCH/2.0)
 
 /* addEdgeLabels:
- * rp and rq are the port points of the tail and head node.
  * Adds label, headlabel and taillabel.
- * The use of 2 and 4 in computing ld.x and ld.y are fudge factors, to
- * introduce a bit of spacing.
  * Updates bounding box.
- * We try to use the actual endpoints of the spline, as they may differ
- * significantly from rp and rq, but if the spline is degenerate (e.g.,
- * the nodes overlap), we use rp and rq.
+ * We use the endpoints of the spline.
  */
-void addEdgeLabels(graph_t* g, edge_t * e, pointf rp, pointf rq)
-{
-#if 0
-    int et = EDGE_TYPE (g);
-    pointf p, q;
-    pointf d;			/* midpoint of segment p-q */
-    point ld;
-    point del;
-    pointf spf;
-    double f, ht, wd, dist2;
-    int leftOf;
-
-    if (ED_label(e) && !ED_label(e)->set) {
-	endPoints(ED_spl(e), &p, &q);
-        if (APPROXEQPT(p, q, MILLIPOINT)) { /* degenerate spline */
-	    p = rp;
-	    q = rq;
-	    spf = p;
-	}
-	else if (et == ET_SPLINE) {
-	    d.x = (q.x + p.x) / 2.;
-	    d.y = (p.y + q.y) / 2.;
-	    spf = dotneato_closest(ED_spl(e), d);
-	}
-	else {   /* ET_PLINE, ET_ORTHO or ET_LINE */
-	    spf = polylineMidpoint (ED_spl(e), &p, &q);
-	}
-	del.x = q.x - p.x;
-	del.y = q.y - p.y;
-	dist2 = del.x*del.x + del.y*del.y;
-	ht = (ED_label(e)->dimen.y + 2)/2.0;
-	if (dist2) {
-	    wd = (MIN(ED_label(e)->dimen.x + 2, MAXLABELWD))/2.0;
-	    leftOf = LEFTOF(p, q, spf);
-	    if ((leftOf && (del.y >= 0)) || (!leftOf && (del.y < 0))) {
-		if (del.x*del.y >= 0)
-		    ht *= -1;
-	    }
-	    else {
-		wd *= -1;
-		if (del.x*del.y < 0)
-		    ht *= -1;
-	    }
-	    f = (del.y*wd - del.x*ht)/dist2;
-	    ld.x = -f*del.y;
-	    ld.y = f*del.x;
-	}
-	else {    /* end points the same */
-	    ld.x = 0;
-	    ld.y = -ht;
-	}
-
-	ED_label(e)->pos.x = spf.x + ld.x;
-	ED_label(e)->pos.y = spf.y + ld.y;
-	ED_label(e)->set = TRUE;
-	updateBB(agraphof(agtail(e)), ED_label(e));
-    }
-#endif
+void addEdgeLabels(edge_t *e) {
     makePortLabels(e);
 }
 
@@ -1422,7 +1356,7 @@ void addEdgeLabels(graph_t* g, edge_t * e, pointf rp, pointf rq)
  * and head is at spl->list[spl->size-l].list[bez->size-1]
  * Return 1 on success
  */
-int place_portlabel(edge_t * e, boolean head_p)
+int place_portlabel(edge_t * e, bool head_p)
 {
     textlabel_t *l;
     splines *spl;
@@ -1436,8 +1370,8 @@ int place_portlabel(edge_t * e, boolean head_p)
     if (ED_edge_type(e) == IGNORED)
 	return 0;
     /* add label here only if labelangle or labeldistance is defined; else, use external label */
-    if ((!E_labelangle || (*(la = AGXGET(e,E_labelangle)) == '\0')) &&
-	(!E_labeldistance || (*(ld = AGXGET(e,E_labeldistance)) == '\0'))) {
+    if ((!E_labelangle || *(la = AGXGET(e,E_labelangle)) == '\0') &&
+	(!E_labeldistance || *(ld = AGXGET(e,E_labeldistance)) == '\0')) {
 	return 0;
     }
 
@@ -1471,7 +1405,7 @@ int place_portlabel(edge_t * e, boolean head_p)
     dist = PORT_LABEL_DISTANCE * late_double(e, E_labeldistance, 1.0, 0.0);
     l->pos.x = pe.x + dist * cos(angle);
     l->pos.y = pe.y + dist * sin(angle);
-    l->set = TRUE;
+    l->set = true;
     return 1;
 }
 
@@ -1482,7 +1416,7 @@ splines *getsplinepoints(edge_t * e)
 
     for (le = e; !(sp = ED_spl(le)) && ED_edge_type(le) != NORMAL;
 	 le = ED_to_orig(le));
-    if (sp == NULL) 
+    if (sp == NULL)
 	agerr (AGERR, "getsplinepoints: no spline points available for edge (%s,%s)\n",
 	    agnameof(agtail(e)), agnameof(aghead(e)));
     return sp;
