@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -18,24 +15,21 @@
  * Written by Emden Gansner
  */
 
-
-#include "config.h"
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#else
-#include "compat_unistd.h"
-#endif
 #include "builddate.h"
-#include "gprstate.h"
-#include "cgraph.h"
-#include "globals.h"
-#include "ingraphs.h"
-#include "compile.h"
-#include "queue.h"
-#include "gvpr.h"
-#include "actions.h"
-#include "sfstr.h"
-#include <error.h>
+#include <gvpr/gprstate.h>
+#include <cgraph/agxbuf.h>
+#include <cgraph/cgraph.h>
+#include <cgraph/exit.h>
+#include <cgraph/stack.h>
+#include <common/globals.h>
+#include <ingraphs/ingraphs.h>
+#include <gvpr/compile.h>
+#include <gvpr/queue.h>
+#include <gvpr/gvpr.h>
+#include <gvpr/actions.h>
+#include <ast/sfstr.h>
+#include <ast/error.h>
 #include <string.h>
 #include <ctype.h>
 #include <setjmp.h>
@@ -108,7 +102,7 @@ static char *gettok(char **sp)
     char c;
     char q = '\0';		/* if non-0, in quote mode with quote char q */
 
-    while (isspace(*rs))
+    while (isspace((int)*rs))
 	rs++;
     if ((c = *rs) == '\0')
 	return NULL;
@@ -179,7 +173,7 @@ static int parseArgs(char *s, int argc, char ***argv)
 }
 
 
-#ifdef _WIN32
+#if defined(_WIN32) && !defined(__MINGW32__)
 #define PATHSEP '\\'
 #define LISTSEP ';'
 #else
@@ -187,17 +181,17 @@ static int parseArgs(char *s, int argc, char ***argv)
 #define LISTSEP ':'
 #endif
 
-static Sfio_t*
-concat (char* pfx, char* sfx, char** sp)
+static char*
+concat (char* pfx, char* sfx)
 {
-    Sfio_t *pathp;
-    if (!(pathp = sfstropen())) {
-	error(ERROR_ERROR, "Could not open buffer");
+    char *sp = malloc(strlen(pfx) + strlen(sfx) + 1);
+    if (sp == NULL) {
+	error(ERROR_ERROR, "Out of memory");
 	return 0;
     }
-    sfprintf(pathp, "%s%s", pfx, sfx);
-    *sp = sfstruse(pathp);
-    return pathp;
+    strcpy(sp, pfx);
+    strcat(sp, sfx);
+    return sp;
 }
 
 /* resolve:
@@ -215,15 +209,11 @@ static char *resolve(char *arg, int Verbose)
     char *cp;
     char c;
     char *fname = 0;
-    Sfio_t *fp;
-    Sfio_t *pathp = NULL;
+    agxbuf fp;
+    char *pathp = NULL;
     size_t sz;
 
-#ifdef WIN32_DLL
-    if (!pathisrelative(arg))
-#else
-    if (strchr(arg, '/'))
-#endif
+    if (strchr(arg, PATHSEP))
 	return strdup(arg);
 
     path = getenv("GVPRPATH");
@@ -231,20 +221,17 @@ static char *resolve(char *arg, int Verbose)
 	path = getenv("GPRPATH");  // deprecated
     if (path && (c = *path)) {
 	if (c == LISTSEP) {
-	    pathp = concat(DFLT_GVPRPATH, path, &path); 
+	    pathp = path = concat(DFLT_GVPRPATH, path);
 	}
 	else if ((c = path[strlen(path)-1]) == LISTSEP) {
-	    pathp = concat(path, DFLT_GVPRPATH, &path); 
+	    pathp = path = concat(path, DFLT_GVPRPATH);
 	}
     }
     else
 	path = DFLT_GVPRPATH;
     if (Verbose)
 	fprintf (stderr, "PATH: %s\n", path);
-    if (!(fp = sfstropen())) {
-	error(ERROR_ERROR, "Could not open buffer");
-	return 0;
-    }
+    agxbinit(&fp, 0, NULL);
 
     while (*path && !fname) {
 	if (*path == LISTSEP) {	/* skip colons */
@@ -254,15 +241,14 @@ static char *resolve(char *arg, int Verbose)
 	cp = strchr(path, LISTSEP);
 	if (cp) {
 	    sz = (size_t) (cp - path);
-	    sfwrite(fp, path, sz);
+	    agxbput_n(&fp, path, sz);
 	    path = cp + 1;	/* skip past current colon */
 	} else {
-	    sz = sfprintf(fp, path);
+	    sz = agxbput(&fp, path);
 	    path += sz;
 	}
-	sfputc(fp, PATHSEP);
-	sfprintf(fp, arg);
-	s = sfstruse(fp);
+	agxbprint(&fp, "%c%s", PATHSEP, arg);
+	s = agxbuse(&fp);
 
 	if (access(s, R_OK) == 0) {
 	    fname = strdup(s);
@@ -272,9 +258,8 @@ static char *resolve(char *arg, int Verbose)
     if (!fname)
 	error(ERROR_ERROR, "Could not find file \"%s\" in GVPRPATH", arg);
 
-    sfclose(fp);
-    if (pathp)
-	sfclose(pathp);
+    agxbfree(&fp);
+    free(pathp);
     if (Verbose)
 	fprintf (stderr, "file %s resolved to %s\n", arg, fname);
     return fname;
@@ -354,12 +339,15 @@ doFlags(char* arg, int argi, int argc, char** argv, options* opts)
 	    opts->verbose = 1;
 	    break;
 	case 'V':
-	    sfprintf(sfstderr, "%s version %s (%s)\n",
-		    Info[0], Info[1], Info[2]);
+	    fprintf(stderr, "%s version %s (%s)\n", Info[0], Info[1], Info[2]);
 	    return 0;
 	    break;
 	case '?':
-	    error(ERROR_USAGE|ERROR_WARNING, "%s", usage);
+	    if (optopt == '\0' || optopt == '?')
+		fprintf(stderr, "Usage: gvpr%s", usage);
+	    else {
+		error(ERROR_USAGE|ERROR_WARNING, "%s", usage);
+	    }
 	    return 0;
 	    break;
 	default :
@@ -391,8 +379,7 @@ freeOpts (options* opts)
 /* scanArgs:
  * Parse command line options.
  */
-static options* scanArgs(int argc, char **argv, gvpropts* uopts)
-{
+static options* scanArgs(int argc, char **argv) {
     int i, nfiles;
     char** input_filenames;
     char* arg;
@@ -595,7 +582,7 @@ static void travBFS(Gpr_t * state, Expr_t* prog, comp_block * xprog)
 static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns * fns)
 {
     Agnode_t *n;
-    queue *stk;
+    gv_stack_t stk = {0};
     Agnode_t *curn;
     Agedge_t *cure;
     Agedge_t *entry;
@@ -604,7 +591,6 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
     nodestream nodes;
     Agedgepair_t seed;
 
-    stk = mkStack();
     nodes.oldroot = 0;
     nodes.prev = 0;
     while ((n = nextNode(state, &nodes))) {
@@ -642,7 +628,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 			evalEdge(state, prog, xprog, cure);
 		} else {
 		    evalEdge(state, prog, xprog, cure);
-		    push(stk, entry);
+		    stack_push_or_exit(&stk, entry);
 		    state->tvedge = entry = cure;
 		    curn = cure->node;
 		    cure = 0;
@@ -657,7 +643,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 		nd = nData(curn);
 		POP(nd);
 		cure = entry;
-		entry = (Agedge_t *) pull(stk);
+		entry = stack_is_empty(&stk) ? NULL : stack_pop(&stk);
 		if (entry == &(seed.out))
 		    state->tvedge = 0;
 		else
@@ -670,7 +656,7 @@ static void travDFS(Gpr_t * state, Expr_t* prog, comp_block * xprog, trav_fns *
 	}
     }
     state->tvedge = 0;
-    freeQ(stk);
+    stack_reset(&stk);
 }
 
 static void travNodes(Gpr_t * state, Expr_t* prog, comp_block * xprog)
@@ -869,12 +855,12 @@ static void *ing_open(char *f)
 
 static Agraph_t *ing_read(void *fp)
 {
-    return readG((Sfio_t *) fp);
+    return readG(fp);
 }
 
 static int ing_close(void *fp)
 {
-    return sfclose((Sfio_t *) fp);
+    return sfclose(fp);
 }
 
 static ingdisc ingDisc = { ing_open, ing_read, ing_close, 0 };
@@ -903,19 +889,19 @@ gvexitf (Expr_t *handle, Exdisc_t *discipline, int v)
 }
 
 static int 
-gverrorf (Expr_t *handle, Exdisc_t *discipline, int level, ...)
+gverrorf (Expr_t *handle, Exdisc_t *discipline, int level, const char *fmt, ...)
 {
     va_list ap;
 
-    va_start(ap, level);
+    va_start(ap, fmt);
     errorv((discipline
-	    && handle) ? *((char **) handle) : (char *) handle, level, ap);
+	    && handle) ? *((char **) handle) : (char *) handle, level, fmt, ap);
     va_end(ap);
 
     if (level >= ERROR_ERROR) {
 	Gpr_t *state = (Gpr_t*)(discipline->user);
 	if (state->flags & GV_USE_EXIT)
-            exit(1);
+            graphviz_exit(1);
 	else if (state->flags & GV_USE_JUMP)
 	    longjmp (jbuf, 1);
     }
@@ -955,7 +941,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	if (uopts->err) setDisc (sfstderr, &errdisc, uopts->err);
     }
 
-    opts = scanArgs(argc, argv, uopts);
+    opts = scanArgs(argc, argv);
     if (opts->state <= 0) {
 	rv = opts->state;
 	goto finish;
@@ -971,7 +957,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
     info.outFile = opts->outFile;
     info.argc = opts->argc;
     info.argv = opts->argv;
-    info.errf = (Exerror_f)gverrorf;
+    info.errf = gverrorf;
     if (uopts) 
 	info.flags = uopts->flags; 
     else
@@ -1013,7 +999,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	incoreGraphs = 0;
 
     if (opts->verbose)
-	sfprintf (sfstderr, "Parse/compile/init: %.2f secs.\n", gvelapsed_sec());
+	fprintf(stderr, "Parse/compile/init: %.2f secs.\n", gvelapsed_sec());
     /* do begin */
     if (xprog->begin_stmt)
 	exeval(xprog->prog, xprog->begin_stmt, state);
@@ -1027,7 +1013,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	
 	if (opts->verbose) gvstart_timer ();
 	for (state->curgraph = nextGraph(ing); state->curgraph; state->curgraph = nextg) {
-	    if (opts->verbose) sfprintf (sfstderr, "Read graph: %.2f secs.\n", gvelapsed_sec());
+	    if (opts->verbose) fprintf(stderr, "Read graph: %.2f secs.\n", gvelapsed_sec());
 	    state->infname = fileName(ing);
 	    if (opts->readAhead)
 		nextg = state->nextgraph = nextGraph(ing);
@@ -1054,7 +1040,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	    state->curobj = (Agobj_t *) state->curgraph;
 	    if (xprog->endg_stmt)
 		exeval(xprog->prog, xprog->endg_stmt, state);
-	    if (opts->verbose) sfprintf (sfstderr, "Finish graph: %.2f secs.\n", gvelapsed_sec());
+	    if (opts->verbose) fprintf(stderr, "Finish graph: %.2f secs.\n", gvelapsed_sec());
 
 	    /* if $O == $G and $T is empty, delete $T */
 	    if ((state->outgraph == state->curgraph) &&
@@ -1081,7 +1067,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
 	    if (opts->verbose) gvstart_timer ();
 	    if (!opts->readAhead)
 		nextg = nextGraph(ing);
-	    if (opts->verbose && nextg) sfprintf (sfstderr, "Read graph: %.2f secs.\n", gvelapsed_sec());
+	    if (opts->verbose && nextg) fprintf(stderr, "Read graph: %.2f secs.\n", gvelapsed_sec());
 	}
     }
 
@@ -1107,3 +1093,7 @@ int gvpr (int argc, char *argv[], gvpropts * uopts)
     return rv;
 }
 
+/**
+ * @dir lib/gvpr
+ * @brief graph pattern scanning and processing language, API gvpr.h
+ */
