@@ -8,13 +8,12 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef QUEUE_H
-#define QUEUE_H
-
 #include "cgraph.h"
 
     typedef Dt_t queue;
@@ -25,19 +24,15 @@ extern "C" {
     extern void freeQ(queue *);
 
 /* pseudo-functions:
-extern queue* mkStack();
 extern queue* mkQueue();
 extern void* pull(queue*);
 extern void* head(queue*);
  */
 
-#define mkStack()  mkQ(Dtstack)
 #define mkQueue()  mkQ(Dtqueue)
 #define pull(q)  (pop(q,1))
 #define head(q)  (pop(q,0))
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
