@@ -8,7 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
+#include <float.h>
 #include <neatogen/neato.h>
 #include <neatogen/dijkstra.h>
 #include <neatogen/bfs.h>
@@ -19,29 +19,15 @@
 #include <neatogen/kkutils.h>
 #include <neatogen/stress.h>
 #include <math.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 
 
-#ifndef HAVE_DRAND48
-extern double drand48(void);
-#endif
-
 #define Dij2			/* If defined, the terms in the stress energy are normalized 
 				   by d_{ij}^{-2} otherwise, they are normalized by d_{ij}^{-1}
 				 */
 
-#ifdef NONCORE
-/* Set 'max_nodes_in_mem' so that 
- * 4*(max_nodes_in_mem^2) is smaller than the available memory (in bytes)
- * 4 = sizeof(float)
- */
-#define max_nodes_in_mem 18000
-#endif
-
- /* relevant when using sparse distance matrix not within subspace */
-#define smooth_pivots true
-
 /* dimensionality of subspace; relevant 
  * when optimizing within subspace) 
  */
@@ -52,7 +38,7 @@ typedef struct {
     int nedges;
     int *edges;
     DistType *edist;
-    boolean free_mem;
+    bool free_mem;
 } dist_data;
 
 static double compute_stressf(float **coords, float *lap, int dim, int n, int exp)
@@ -77,14 +63,14 @@ static double compute_stressf(float **coords, float *lap, int dim, int n, int ex
 	    if (exp == 2) {
 #ifdef Dij2
 		Dij = 1.0 / sqrt(lap[count]);
-		sum += (Dij - dist) * (Dij - dist) * (lap[count]);
+		sum += (Dij - dist) * (Dij - dist) * lap[count];
 #else
 		Dij = 1.0 / lap[count];
-		sum += (Dij - dist) * (Dij - dist) * (lap[count]);
+		sum += (Dij - dist) * (Dij - dist) * lap[count];
 #endif
 	    } else {
 		Dij = 1.0 / lap[count];
-		sum += (Dij - dist) * (Dij - dist) * (lap[count]);
+		sum += (Dij - dist) * (Dij - dist) * lap[count];
 	    }
 	}
     }
@@ -321,7 +307,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
     double *b_restricted;
     double L_ij;
     double old_stress, new_stress;
-    boolean converged;
+    bool converged;
 
     for (i = 0; i < subspace_dim; i++) {
 	subspace[i] = d_storage + i * n;
@@ -437,7 +423,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 	    distances[i].edist = N_GNEW(n - 1, DistType);
 	    distances[i].nedges = n - 1;
 	    nedges += n - 1;
-	    distances[i].free_mem = TRUE;
+	    distances[i].free_mem = true;
 	    index = CenterIndex[i];
 	    for (j = 0; j < i; j++) {
 		distances[i].edges[j] = j;
@@ -481,9 +467,9 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 	    available_space = (dist_bound + 1) * n;
 	    storage1 = N_GNEW(available_space, int);
 	    storage2 = N_GNEW(available_space, DistType);
-	    distances[i].free_mem = TRUE;
+	    distances[i].free_mem = true;
 	} else {
-	    distances[i].free_mem = FALSE;
+	    distances[i].free_mem = false;
 	}
 	distances[i].edges = storage1;
 	distances[i].edist = storage2;
@@ -593,7 +579,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 	/* random initialization */
 	for (k = 0; k < dim; k++) {
 	    for (i = 0; i < subspace_dim; i++) {
-		directions[k][i] = (double) (rand()) / RAND_MAX;
+		directions[k][i] = (double) rand() / RAND_MAX;
 	    }
 	}
     }
@@ -625,7 +611,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
     b = N_GNEW(n, double);
     b_restricted = N_GNEW(subspace_dim, double);
     old_stress = compute_stress1(coords, distances, dim, n, exp);
-    for (converged = FALSE, iterations = 0;
+    for (converged = false, iterations = 0;
 	 iterations < n_iterations && !converged; iterations++) {
 
 	/* Axis-by-axis optimization: */
@@ -654,7 +640,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 				     b_restricted);
 	    if (conjugate_gradient_f(matrix, directions[k], b_restricted,
 				 subspace_dim, conj_tol, subspace_dim,
-				 FALSE)) {
+				 false)) {
 		iterations = -1;
 		goto finish0;
 	    }
@@ -662,11 +648,9 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 					     directions[k], coords[k]);
 	}
 
-	if ((converged = (iterations % 2 == 0))) {	/* check for convergence each two iterations */
+	if ((converged = iterations % 2 == 0)) {	/* check for convergence each two iterations */
 	    new_stress = compute_stress1(coords, distances, dim, n, exp);
-	    converged =
-		fabs(new_stress - old_stress) / (new_stress + 1e-10) <
-		Epsilon;
+	    converged = fabs(new_stress - old_stress) / (new_stress + 1e-10) < Epsilon;
 	    old_stress = new_stress;
 	}
     }
@@ -780,7 +764,7 @@ float *compute_apsp_packed(vtx_data * graph, int n)
     for (i = 0; i < n; i++) {
 	bfs(i, graph, n, Di, &Q);
 	for (j = i; j < n; j++) {
-	    Dij[count++] = ((float) Di[j]);
+	    Dij[count++] = (float)Di[j];
 	}
     }
     free(Di);
@@ -904,7 +888,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
     int step;
     float val;
     double old_stress, new_stress;
-    boolean converged;
+    bool converged;
     float **b = NULL;
     float *tmp_coords = NULL;
     float *dist_accumulator = NULL;
@@ -916,10 +900,6 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 #ifdef ALTERNATIVE_STRESS_CALC
     double mat_stress;
 #endif
-#ifdef NONCORE
-    FILE *fp = NULL;
-#endif
-
 
 	/*************************************************
 	** Computation of full, dense, unrestricted k-D ** 
@@ -974,14 +954,14 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	** Layout initialization **
 	**************************/
 
-    if (smart_ini && (n > 1)) {
+    if (smart_ini && n > 1) {
 	havePinned = 0;
 	/* optimize layout quickly within subspace */
 	/* perform at most 50 iterations within 30-D subspace to 
 	   get an estimate */
 	if (sparse_stress_subspace_majorization_kD(graph, n, nedges_graph,
 					       d_coords, dim, smart_ini, exp,
-					       (model == MODEL_SUBSET), 50,
+					       model == MODEL_SUBSET, 50,
 					       neighborhood_radius_subspace,
 					       num_pivots_stress) < 0) {
 	    iterations = -1;
@@ -1010,7 +990,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
     }
     if (Verbose)
 	fprintf(stderr, ": %.2f sec", elapsed_sec());
-    if ((n == 1) || (maxi == 0))
+    if (n == 1 || maxi == 0)
 	return 0;
 
     if (Verbose) {
@@ -1023,7 +1003,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
     for (i = 0; i < dim; i++) {
 	coords[i] = f_storage + i * n;
 	for (j = 0; j < n; j++) {
-	    coords[i][j] = ((float) d_coords[i][j]);
+	    coords[i][j] = (float)d_coords[i][j];
 	}
     }
 
@@ -1031,7 +1011,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
     /* which is \sum_{i<j} w_{ij}d_{ij}^2 */
     if (exp) {
 #ifdef Dij2
-	constant_term = ((float) n * (n - 1) / 2);
+	constant_term = (float)n * (n - 1) / 2;
 #else
 	constant_term = 0;
 	for (count = 0, i = 0; i < n - 1; i++) {
@@ -1084,16 +1064,6 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	lap2[count] = degrees[i];
     }
 
-#ifdef NONCORE
-    if (n > max_nodes_in_mem) {
-#define FILENAME "tmp_Dij$$$.bin"
-	fp = fopen(FILENAME, "wb");
-	fwrite(lap2, sizeof(float), lap_length, fp);
-	fclose(fp);
-	fp = NULL;
-    }
-#endif
-
 	/*************************
 	** Layout optimization  **
 	*************************/
@@ -1106,32 +1076,17 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 
     tmp_coords = N_NEW(n, float);
     dist_accumulator = N_NEW(n, float);
-    lap1 = NULL;
-#ifdef NONCORE
-    if (n <= max_nodes_in_mem) {
-	lap1 = N_NEW(lap_length, float);
-    } else {
-	lap1 = lap2;
-	fp = fopen(FILENAME, "rb");
-	fgetpos(fp, &pos);
-    }
-#else
     lap1 = N_NEW(lap_length, float);
-#endif
 
 
-#ifdef USE_MAXFLOAT
-    old_stress = MAXFLOAT;	/* at least one iteration */
-#else
     old_stress = MAXDOUBLE;	/* at least one iteration */
-#endif
     if (Verbose) {
 	fprintf(stderr, ": %.2f sec\n", elapsed_sec());
 	fprintf(stderr, "Solving model: ");
 	start_timer();
     }
 
-    for (converged = FALSE, iterations = 0;
+    for (converged = false, iterations = 0;
 	 iterations < maxi && !converged; iterations++) {
 
 	/* First, construct Laplacian of 1/(d_ij*|p_i-p_j|)  */
@@ -1139,15 +1094,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	memset(degrees, 0, n * sizeof(DegType));
 	if (exp == 2) {
 #ifdef Dij2
-#ifdef NONCORE
-	    if (n <= max_nodes_in_mem) {
-		sqrt_vecf(lap_length, lap2, lap1);
-	    } else {
-		sqrt_vec(lap_length, lap1);
-	    }
-#else
 	    sqrt_vecf(lap_length, lap2, lap1);
-#endif
 #endif
 	}
 	for (count = 0, i = 0; i < n - 1; i++) {
@@ -1168,8 +1115,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	    invert_sqrt_vec(len, dist_accumulator);
 	    /* detect overflows */
 	    for (j = 0; j < len; j++) {
-		if (dist_accumulator[j] >= MAXFLOAT
-		    || dist_accumulator[j] < 0) {
+		if (dist_accumulator[j] >= FLT_MAX || dist_accumulator[j] < 0) {
 		    dist_accumulator[j] = 0;
 		}
 	    }
@@ -1214,13 +1160,6 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	}
 	new_stress *= 2;
 	new_stress += constant_term;	/* only after mult by 2 */
-#ifdef NONCORE
-	if (n > max_nodes_in_mem) {
-	    /* restore lap2 from memory */
-	    fsetpos(fp, &pos);
-	    fread(lap2, sizeof(float), lap_length, fp);
-	}
-#endif
 	for (k = 0; k < dim; k++) {
 	    right_mult_with_vector_ff(lap2, n, coords[k], tmp_coords);
 	    new_stress -= vectors_inner_productf(n, coords[k], tmp_coords);
@@ -1240,8 +1179,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	{
 	    double diff = old_stress - new_stress;
 	    double change = fabs(diff);
-	    converged = (((change / old_stress) < Epsilon)
-			 || (new_stress < Epsilon));
+	    converged = change / old_stress < Epsilon || new_stress < Epsilon;
 	}
 	old_stress = new_stress;
 
@@ -1267,7 +1205,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 		}
 	    }
 	}
-	if (Verbose && (iterations % 5 == 0)) {
+	if (Verbose && iterations % 5 == 0) {
 	    fprintf(stderr, "%.3f ", new_stress);
 	    if ((iterations + 5) % 50 == 0)
 		fprintf(stderr, "\n");
@@ -1284,10 +1222,6 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	    d_coords[i][j] = coords[i][j];
 	}
     }
-#ifdef NONCORE
-    if (fp)
-	fclose(fp);
-#endif
 finish1:
     free(f_storage);
     free(coords);
