@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -19,10 +16,9 @@
 
 #include <math.h>
 #include <assert.h>
-#include "render.h"
-#include "pack.h"
-#include "pointset.h"
-#include <assert.h>
+#include <common/render.h>
+#include <pack/pack.h>
+#include <common/pointset.h>
 
 #define strneq(a,b,n)		(!strncmp(a,b,n))
 
@@ -53,7 +49,7 @@ typedef struct {
  * quadratic equation al^2 +bl + c, where a, b and
  * c are defined below.
  */
-static int computeStep(int ng, boxf* bbs, int margin)
+static int computeStep(int ng, boxf* bbs, unsigned int margin)
 {
     double l1, l2;
     double a, b, c, d, r;
@@ -98,18 +94,17 @@ static int computeStep(int ng, boxf* bbs, int margin)
  */
 static int cmpf(const void *X, const void *Y)
 {
-    ginfo *x = *(ginfo **) X;
-    ginfo *y = *(ginfo **) Y;
+    const ginfo *x = *(ginfo *const *) X;
+    const ginfo *y = *(ginfo *const *) Y;
     /* flip order to get descending array */
-    return (y->perim - x->perim);
+    return y->perim - x->perim;
 }
 
 /* fillLine:
  * Mark cells crossed by line from cell p to cell q.
  * Bresenham's algorithm, from Graphics Gems I, pp. 99-100.
  */
-/* static  */
-void fillLine(pointf p, pointf q, PointSet * ps)
+static void fillLine(pointf p, pointf q, PointSet * ps)
 {
     int x1 = ROUND(p.x);
     int y1 = ROUND(p.y);
@@ -118,10 +113,10 @@ void fillLine(pointf p, pointf q, PointSet * ps)
     int d, x, y, ax, ay, sx, sy, dx, dy;
 
     dx = x2 - x1;
-    ax = ABS(dx) << 1;
+    ax = abs(dx) << 1;
     sx = SGN(dx);
     dy = y2 - y1;
-    ay = ABS(dy) << 1;
+    ay = abs(dy) << 1;
     sy = SGN(dy);
 
 /* fprintf (stderr, "fillLine %d %d - %d %d\n", x1,y1,x2,y2); */
@@ -224,7 +219,8 @@ fillEdge(Agedge_t * e, point p, PointSet * ps, int dx, int dy,
  * the graph.
  */
 static void
-genBox(boxf bb0, ginfo * info, int ssize, int margin, point center, char* s)
+genBox(boxf bb0, ginfo * info, int ssize, unsigned int margin, point center,
+	char* s)
 {
     PointSet *ps;
     int W, H;
@@ -289,7 +285,7 @@ genPoly(Agraph_t * root, Agraph_t * g, ginfo * info,
     int x, y;
     int dx, dy;
     graph_t *subg;
-    int margin = pinfo->margin;
+    unsigned int margin = pinfo->margin;
     int doSplines = pinfo->doSplines;
     box bb;
 
@@ -317,7 +313,7 @@ genPoly(Agraph_t * root, Agraph_t * g, ginfo * info,
 	for (i = 1; i <= GD_n_cluster(g); i++) {
 	    subg = GD_clust(g)[i];
 	    BF2B(GD_bb(subg), bb);
-	    if ((bb.UR.x > bb.LL.x) && (bb.UR.y > bb.LL.y)) {
+	    if (bb.UR.x > bb.LL.x && bb.UR.y > bb.LL.y) {
 		MOVEPT(bb.LL);
 		MOVEPT(bb.UR);
 		bb.LL.x -= margin;
@@ -488,7 +484,7 @@ placeFixed(ginfo * info, PointSet * ps, point * place, point center)
  */
 static void
 placeGraph(int i, ginfo * info, PointSet * ps, point * place, int step,
-	   int margin, boxf* bbs)
+	   unsigned int margin, boxf* bbs)
 {
     int x, y;
     int W, H;
@@ -569,8 +565,8 @@ static packval_t* userVals;
  */
 static int ucmpf(const void *X, const void *Y)
 {
-    ainfo* x = *(ainfo **) X;
-    ainfo* y = *(ainfo **) Y;
+    const ainfo* x = *(ainfo *const *) X;
+    const ainfo* y = *(ainfo *const *) Y;
 
     int dX = userVals[x->index];
     int dY = userVals[y->index];
@@ -584,15 +580,8 @@ static int ucmpf(const void *X, const void *Y)
  */
 static int acmpf(const void *X, const void *Y)
 {
-    ainfo* x = *(ainfo **) X;
-    ainfo* y = *(ainfo **) Y;
-#if 0
-    if (x->height < y->height) return 1;
-    else if (x->height > y->height) return -1;
-    else if (x->width < y->width) return 1;
-    else if (x->width > y->width) return -1;
-    else return 0;
-#endif
+    const ainfo* x = *(ainfo *const *) X;
+    const ainfo* y = *(ainfo *const *) Y;
     double dX = x->height + x->width; 
     double dY = y->height + y->width; 
     if (dX < dY) return 1;
@@ -762,7 +751,7 @@ polyRects(int ng, boxf* gs, pack_info * pinfo)
     ps = newPS();
     places = N_NEW(ng, point);
     for (i = 0; i < ng; i++)
-	placeGraph(i, sinfo[i], ps, places + (sinfo[i]->index),
+	placeGraph(i, sinfo[i], ps, places + sinfo[i]->index,
 		       stepSize, pinfo->margin, gs);
 
     free(sinfo);
@@ -813,7 +802,7 @@ polyGraphs(int ng, Agraph_t ** gs, Agraph_t * root, pack_info * pinfo)
     point *places;
     Dict_t *ps;
     int i;
-    boolean *fixed = pinfo->fixed;
+    bool *fixed = pinfo->fixed;
     int fixed_cnt = 0;
     box bb, fixed_bb = { {0, 0}, {0, 0} };
     point center;
@@ -884,17 +873,16 @@ polyGraphs(int ng, Agraph_t ** gs, Agraph_t * root, pack_info * pinfo)
     if (fixed) {
 	for (i = 0; i < ng; i++) {
 	    if (fixed[i])
-		placeFixed(sinfo[i], ps, places + (sinfo[i]->index),
-			   center);
+		placeFixed(sinfo[i], ps, places + sinfo[i]->index, center);
 	}
 	for (i = 0; i < ng; i++) {
 	    if (!fixed[i])
-		placeGraph(i, sinfo[i], ps, places + (sinfo[i]->index),
+		placeGraph(i, sinfo[i], ps, places + sinfo[i]->index,
 			   stepSize, pinfo->margin, bbs);
 	}
     } else {
 	for (i = 0; i < ng; i++)
-	    placeGraph(i, sinfo[i], ps, places + (sinfo[i]->index),
+	    placeGraph(i, sinfo[i], ps, places + sinfo[i]->index,
 		       stepSize, pinfo->margin, bbs);
     }
 
@@ -940,7 +928,7 @@ point *putGraphs(int ng, Agraph_t ** gs, Agraph_t * root,
 	    pinfo->vals = N_NEW(ng, packval_t);
 	    for (i = 0; i < ng; i++) {
 		s = agget (gs[i], "sortv");
-		if (s && (sscanf (s, "%d", &v) > 0) && (v >= 0))
+		if (s && sscanf(s, "%d", &v) > 0 && v >= 0)
 		    pinfo->vals[i] = v;
 	    }
 
@@ -959,7 +947,7 @@ point *
 putRects(int ng, boxf* bbs, pack_info* pinfo)
 {
     if (ng <= 0) return NULL;
-    if ((pinfo->mode == l_node) || (pinfo->mode == l_clust)) return NULL;
+    if (pinfo->mode == l_node || pinfo->mode == l_clust) return NULL;
     if (pinfo->mode == l_graph)
 	return polyRects (ng, bbs, pinfo);
     else if (pinfo->mode == l_array)
@@ -1187,7 +1175,7 @@ packSubgraphs(int ng, Agraph_t ** gs, Agraph_t * root, pack_info * info)
  * Pack subgraphs followed by postprocessing.
  */
 int 
-pack_graph(int ng, Agraph_t** gs, Agraph_t* root, boolean* fixed)
+pack_graph(int ng, Agraph_t** gs, Agraph_t* root, bool *fixed)
 {
     int ret;
     pack_info info;
@@ -1204,9 +1192,7 @@ pack_graph(int ng, Agraph_t** gs, Agraph_t* root, boolean* fixed)
 #define ASPECT "aspect"
 #define SLEN(s) (sizeof(s)/sizeof(char) - 1)
 
-static char*
-chkFlags (char* p, pack_info* pinfo)
-{
+static const char*chkFlags(const char *p, pack_info *pinfo) {
     int c, more;
 
     if (*p != '_') return p;
@@ -1284,7 +1270,7 @@ mode2Str (pack_mode m)
  * If not defined, return dflt
  */
 pack_mode 
-parsePackModeInfo(char* p, pack_mode dflt, pack_info* pinfo)
+parsePackModeInfo(const char* p, pack_mode dflt, pack_info* pinfo)
 {
     float v;
     int i;
@@ -1306,18 +1292,12 @@ parsePackModeInfo(char* p, pack_mode dflt, pack_info* pinfo)
 	    }
 	    else if (strneq(p, ASPECT, SLEN(ASPECT))) {
 		pinfo->mode = l_aspect;
-		if ((sscanf (p + SLEN(ARRAY), "%f", &v)>0) && (v > 0))
+		if (sscanf(p + SLEN(ARRAY), "%f", &v) > 0 && v > 0)
 		    pinfo->aspect = v;
 		else
 		    pinfo->aspect = 1;
 	    }
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 'b':
-	    if (streq(p, "bisect"))
-		pinfo->mode = l_bisect;
-	    break;
-#endif
 	case 'c':
 	    if (streq(p, "cluster"))
 		pinfo->mode = l_clust;
@@ -1326,22 +1306,10 @@ parsePackModeInfo(char* p, pack_mode dflt, pack_info* pinfo)
 	    if (streq(p, "graph"))
 		pinfo->mode = l_graph;
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 'h':
-	    if (streq(p, "hull"))
-		pinfo->mode = l_hull;
-	    break;
-#endif
 	case 'n':
 	    if (streq(p, "node"))
 		pinfo->mode = l_node;
 	    break;
-#ifdef NOT_IMPLEMENTED
-	case 't':
-	    if (streq(p, "tile"))
-		pinfo->mode = l_tile;
-	    break;
-#endif
 	}
     }
 
@@ -1385,9 +1353,9 @@ int getPack(Agraph_t * g, int not_def, int dflt)
     int v = not_def;
 
     if ((p = agget(g, "pack"))) {
-	if ((sscanf(p, "%d", &i) == 1) && (i >= 0))
+	if (sscanf(p, "%d", &i) == 1 && i >= 0)
 	    v = i;
-	else if ((*p == 't') || (*p == 'T'))
+	else if (*p == 't' || *p == 'T')
 	    v = dflt;
     }
 
@@ -1401,13 +1369,11 @@ getPackInfo(Agraph_t * g, pack_mode dflt, int dfltMargin, pack_info* pinfo)
 
     pinfo->margin = getPack(g, dfltMargin, dfltMargin);
     if (Verbose) {
-	fprintf (stderr, "  margin %d\n", pinfo->margin);
+	fprintf (stderr, "  margin %u\n", pinfo->margin);
     }
     pinfo->doSplines = 0;
-    pinfo->fixed = 0;
+    pinfo->fixed = NULL;
     getPackModeInfo(g, dflt, pinfo);
 
     return pinfo->mode;
 }
-
-
