@@ -10,6 +10,7 @@
 
 #include	<sfio/sfhdr.h>
 #include	<stddef.h>
+#include	<stdint.h>
 
 /*	Write with discipline.
 **
@@ -33,7 +34,7 @@ static ssize_t sfoutput(Sfio_t * f, char *buf, size_t n)
 	    while ((ssize_t) n >= _Sfpage) {	/* see if a hole of 0's starts here */
 		sp = buf + 1;
 		if (buf[0] == 0 && buf[_Sfpage - 1] == 0) {	/* check byte at a time until int-aligned */
-		    while (((ulong) sp) % sizeof(int)) {
+		    while ((uintptr_t)sp % sizeof(int)) {
 			if (*sp != 0)
 			    goto chk_hole;
 			sp += 1;
@@ -72,7 +73,7 @@ static ssize_t sfoutput(Sfio_t * f, char *buf, size_t n)
 		buf = endbuf;
 		n = s = 0;
 	    }
-	    if ((wr = write(f->file, wbuf, buf - wbuf)) > 0) {
+	    if ((wr = write(f->file, wbuf, (size_t)(buf - wbuf))) > 0) {
 		w += wr;
 		f->bits &= (unsigned short)~SF_HOLE;
 	    }
@@ -170,7 +171,7 @@ ssize_t sfwr(Sfio_t * f, const void * buf, size_t n,
 		    goto do_write;
 	    } else {
 	      do_write:
-		if ((w = write(f->file, (char *) buf, n)) > 0)
+		if ((w = write(f->file, buf, n)) > 0)
 		    f->bits &= (unsigned short)~SF_HOLE;
 	    }
 
@@ -180,7 +181,7 @@ ssize_t sfwr(Sfio_t * f, const void * buf, size_t n,
 	    if (w > 0) {
 		if (!(f->bits & SF_DCDOWN)) {
 		    if (f->flags & (SF_APPENDWR | SF_PUBLIC))
-			f->here = SFSK(f, (Sfoff_t) 0, SEEK_CUR, dc);
+			f->here = SFSK(f, 0, SEEK_CUR, dc);
 		    else
 			f->here += w;
 		    if (f->extent >= 0 && f->here > f->extent)
