@@ -12,7 +12,7 @@
 #include <sparse/general.h>
 #include <sparse/SparseMatrix.h>
 #include <sparse/clustering.h>
-
+#include <stdbool.h>
 
 
 static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_init(SparseMatrix A, int level){
@@ -20,7 +20,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_init(Sp
   int n = A->n, i, j;
 
   assert(A->type == MATRIX_TYPE_REAL);
-  assert(SparseMatrix_is_symmetric(A, FALSE));
+  assert(SparseMatrix_is_symmetric(A, false));
 
   if (!A) return NULL;
   assert(A->m == n);
@@ -33,22 +33,22 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_init(Sp
   grid->next = NULL;
   grid->prev = NULL;
   grid->delete_top_level_A = FALSE;
-  grid->matching = MALLOC(sizeof(real)*(n));
+  grid->matching = MALLOC(sizeof(double)*(n));
   grid->deg = NULL;
   grid->agglomerate_regardless = FALSE;
 
   if (level == 0){
-    real modularity = 0;
+    double modularity = 0;
     int *ia = A->ia, *ja = A->ja, n = A->n;
-    real deg_total = 0;
-    real *deg, *a = (real*) (A->a);
-    real *indeg;
+    double deg_total = 0;
+    double *deg, *a = (double*) (A->a);
+    double *indeg;
 
     grid->deg_total = 0.;
-    grid->deg = MALLOC(sizeof(real)*(n));
+    grid->deg = MALLOC(sizeof(double)*(n));
     deg = grid->deg;
 
-    indeg = MALLOC(sizeof(real)*n);
+    indeg = MALLOC(sizeof(double)*n);
     for (i = 0; i < n; i++){
       deg[i] = 0;
       indeg[i] = 0.;
@@ -65,7 +65,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_init(Sp
     grid->deg_total = deg_total;
     grid->deg = deg;
     grid->modularity = modularity;
-    FREE(indeg);
+    free(indeg);
   }
 
 
@@ -83,32 +83,32 @@ static void Multilevel_Modularity_Clustering_delete(Multilevel_Modularity_Cluste
   }
   SparseMatrix_delete(grid->P);
   SparseMatrix_delete(grid->R);
-  FREE(grid->matching);
-  FREE(grid->deg);
+  free(grid->matching);
+  free(grid->deg);
 
   Multilevel_Modularity_Clustering_delete(grid->next);
-  FREE(grid);
+  free(grid);
 }
 
 static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establish(Multilevel_Modularity_Clustering grid, int ncluster_target){
   int *matching = grid->matching;
   SparseMatrix A = grid->A;
   int n = grid->n, level = grid->level, nc = 0;
-  real modularity = 0;
+  double modularity = 0;
   int *ia = A->ia, *ja = A->ja;
-  real *a;
-  real *deg = grid->deg;
-  real *deg_new;
+  double *a;
+  double *deg = grid->deg;
+  double *deg_new;
   int i, j, jj, jc, jmax;
-  real inv_deg_total = 1./(grid->deg_total);
-  real *deg_inter, gain;
+  double inv_deg_total = 1./(grid->deg_total);
+  double *deg_inter, gain;
   int *mask;
-  real maxgain;
-  real total_gain = 0;
+  double maxgain;
+  double total_gain = 0;
   modularity = grid->modularity;
 
-  deg_new = MALLOC(sizeof(real)*n);
-  deg_inter = MALLOC(sizeof(real)*n);
+  deg_new = MALLOC(sizeof(double)*n);
+  deg_inter = MALLOC(sizeof(double)*n);
   mask = MALLOC(sizeof(int)*n);
   for (i = 0; i < n; i++) mask[i] = -1;
 
@@ -118,7 +118,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establi
   /* gain in merging node i into cluster j is
      deg(i,j)/deg_total - 2*deg(i)*deg(j)/deg_total^2
   */
-  a = (real*) A->a;
+  a = (double*) A->a;
   for (i = 0; i < n; i++){
     if (matching[i] != UNMATCHED) continue;
     /* accumulate connections between i and clusters */
@@ -194,13 +194,13 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establi
       } else if (n - ncluster_target <= ncluster_target - nc){/* ncluster_target close to n */
 	fprintf(stderr,"ncluster_target = %d, close to n=%d\n", ncluster_target, n);
 	for (i = 0; i < n; i++) matching[i] = i;
-	FREE(deg_new);
+	free(deg_new);
 	goto RETURN;
       }
     } else if (n < ncluster_target){
       fprintf(stderr,"n < target\n");
       for (i = 0; i < n; i++) matching[i] = i;
-      FREE(deg_new);
+      free(deg_new);
       goto RETURN;
     }
   }
@@ -208,25 +208,25 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establi
   if (nc >= 1 && (total_gain > 0 || nc < n)){
     /* now set up restriction and prolongation operator */
     SparseMatrix P, R, R0, B, cA;
-    real one = 1.;
+    double one = 1.;
     Multilevel_Modularity_Clustering cgrid;
 
     R0 = SparseMatrix_new(nc, n, 1, MATRIX_TYPE_REAL, FORMAT_COORD);
     for (i = 0; i < n; i++){
       jj = matching[i];
-      SparseMatrix_coordinate_form_add_entries(R0, 1, &jj, &i, &one);
+      SparseMatrix_coordinate_form_add_entry(R0, jj, i, &one);
     }
     R = SparseMatrix_from_coordinate_format(R0);
     SparseMatrix_delete(R0);
     P = SparseMatrix_transpose(R);
     B = SparseMatrix_multiply(R, A);
     if (!B) {
-      FREE(deg_new);
+      free(deg_new);
       goto RETURN;
     }
     cA = SparseMatrix_multiply(B, P); 
     if (!cA) {
-      FREE(deg_new);
+      free(deg_new);
       goto RETURN;
     }
     SparseMatrix_delete(B);
@@ -234,7 +234,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establi
     grid->R = R;
     level++;
     cgrid = Multilevel_Modularity_Clustering_init(cA, level); 
-    deg_new = REALLOC(deg_new, nc*sizeof(real));
+    deg_new = REALLOC(deg_new, nc*sizeof(double));
     cgrid->deg = deg_new;
     cgrid->modularity = grid->modularity + total_gain;
     cgrid->deg_total = grid->deg_total;
@@ -245,19 +245,19 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_establi
     /* if we want a small number of cluster but right now we have too many, we will force agglomeration */
     if (ncluster_target > 0 && nc > ncluster_target && !(grid->agglomerate_regardless)){
       grid->agglomerate_regardless = TRUE;
-      FREE(deg_inter);
-      FREE(mask);
-      FREE(deg_new);
+      free(deg_inter);
+      free(mask);
+      free(deg_new);
       return Multilevel_Modularity_Clustering_establish(grid, ncluster_target);
     }
     /* no more improvement, stop and final clustering found */
     for (i = 0; i < n; i++) matching[i] = i;
-    FREE(deg_new);
+    free(deg_new);
   }
 
  RETURN:
-  FREE(deg_inter);
-  FREE(mask);
+  free(deg_inter);
+  free(mask);
   return grid;
 }
 
@@ -273,7 +273,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_new(Spa
   Multilevel_Modularity_Clustering grid;
   SparseMatrix A = A0;
 
-  if (!SparseMatrix_is_symmetric(A, FALSE) || A->type != MATRIX_TYPE_REAL){
+  if (!SparseMatrix_is_symmetric(A, false) || A->type != MATRIX_TYPE_REAL){
     A = SparseMatrix_get_real_adjacency_matrix_symmetrized(A);
   }
   grid = Multilevel_Modularity_Clustering_init(A, 0);
@@ -286,7 +286,7 @@ static Multilevel_Modularity_Clustering Multilevel_Modularity_Clustering_new(Spa
 
 
 static void hierachical_modularity_clustering(SparseMatrix A, int ncluster_target,
-					      int *nclusters, int **assignment, real *modularity, int *flag){
+					      int *nclusters, int **assignment, double *modularity, int *flag){
   /* find a clustering of vertices by maximize modularity
      A: symmetric square matrix n x n. If real value, value will be used as edges weights, otherwise edge weights are considered as 1.
 
@@ -305,7 +305,7 @@ static void hierachical_modularity_clustering(SparseMatrix A, int ncluster_targe
   Multilevel_Modularity_Clustering grid, cgrid;
   int *matching, i;
   SparseMatrix P;
-  real *u;
+  double *u;
   assert(A->m == A->n);
 
   *modularity = 0.;
@@ -321,16 +321,16 @@ static void hierachical_modularity_clustering(SparseMatrix A, int ncluster_targe
   }
 
   /* project clustering up */
-  u =  MALLOC(sizeof(real)*cgrid->n);
-  for (i = 0; i < cgrid->n; i++) u[i] = (real) (cgrid->matching)[i];
+  u =  MALLOC(sizeof(double)*cgrid->n);
+  for (i = 0; i < cgrid->n; i++) u[i] = (double) (cgrid->matching)[i];
   *nclusters = cgrid->n;
   *modularity = cgrid->modularity;
 
   while (cgrid->prev){
-    real *v = NULL;
+    double *v = NULL;
     P = cgrid->prev->P;
     SparseMatrix_multiply_vector(P, u, &v, FALSE);
-    FREE(u);
+    free(u);
     u = v;
     cgrid = cgrid->prev;
   }
@@ -342,16 +342,15 @@ static void hierachical_modularity_clustering(SparseMatrix A, int ncluster_targe
     *assignment = matching;
   }
   for (i = 0; i < grid->n; i++) (matching)[i] = (int) u[i];
-  FREE(u);
+  free(u);
 
   Multilevel_Modularity_Clustering_delete(grid);
-  
 }
 
 
 
 void modularity_clustering(SparseMatrix A, int inplace, int ncluster_target, int use_value,
-			   int *nclusters, int **assignment, real *modularity, int *flag){
+			   int *nclusters, int **assignment, double *modularity, int *flag){
   /* find a clustering of vertices by maximize modularity
      A: symmetric square matrix n x n. If real value, value will be used as edges weights, otherwise edge weights are considered as 1.
      inplace: whether A can e modified. If true, A will be modified by removing diagonal.
@@ -371,7 +370,7 @@ void modularity_clustering(SparseMatrix A, int inplace, int ncluster_target, int
   
   assert(A->m == A->n);
 
-  B = SparseMatrix_symmetrize(A, FALSE);
+  B = SparseMatrix_symmetrize(A, false);
 
   if (!inplace && B == A) {
     B = SparseMatrix_copy(A);
