@@ -1,8 +1,17 @@
+"""
+Tests of large and/or expensive graphs.
+"""
+
 import os
+from pathlib import Path
 import platform
 import subprocess
+import sys
 import pytest
 
+sys.path.append(os.path.join(os.path.dirname(__file__), "../../../rtest"))
+from gvtest import dot #pylint: disable=wrong-import-position
+
 @pytest.mark.skipif(platform.system() == "Windows" and
                     platform.architecture()[0] == "32bit",
                     reason="https://gitlab.com/graphviz/graphviz/-/issues/1710")
@@ -30,3 +39,9 @@ def test_long_chain():
   subprocess.check_call([
     "dot", "-Tsvg", "-O", os.devnull
   ])
+
+def test_wide_clusters():
+  """
+  A simple regression test for https://gitlab.com/graphviz/graphviz/-/issues/2080#
+  """
+  dot("svg", Path(__file__).parent / "wide_clusters")
