@@ -75,9 +75,6 @@
 /* Define if you have the GDI+ framework for Windows */
 /* #undef HAVE_GDIPLUS */
 
-/* Define if you have the gdk_pixbuf library */
-/* #undef HAVE_GDK_PIXBUF */
-
 /* Define if the GD library has the GD_FONTCONFIG feature */
 #define HAVE_GD_FONTCONFIG 1
 
@@ -99,9 +96,6 @@
 /* Define if you have the glade library */
 #define HAVE_GLADE 1
 
-/* Define if you have the glitz library */
-/* #undef HAVE_GLITZ */
-
 /* Define if you have the gs library */
 /* #undef HAVE_GS */
 
@@ -111,9 +105,6 @@
 /* Define if you have the gtkgl library */
 /* #undef HAVE_GTKGL */
 
-/* Define if you have the gtkglext library */
-#define HAVE_GTKGLEXT 1
-
 /* Define if you have the gts library */
 /* #undef HAVE_GTS */
 
@@ -135,9 +126,6 @@
 /* Define if you have the PNG library */
 #define HAVE_LIBPNG 1
 
-/* Define if you have the XPM library */
-/* #undef HAVE_LIBXPMFORLEFTY */
-
 /* Define if you have the Z library */
 #define HAVE_LIBZ 1
 
@@ -174,9 +162,6 @@
 /* Define to 1 if you have the `srand48' function. */
 /* #undef HAVE_SRAND48 */
 
-/* Define to 1 if you have the <strings.h> header file. */
-//#define HAVE_STRINGS_H 1
-
 /* Define to 1 if you have the <sys/inotify.h> header file. */
 /* #undef HAVE_SYS_INOTIFY_H */
 
@@ -213,9 +198,6 @@
 /* Define if triangle.[ch] are available. */
 /* #undef HAVE_TRIANGLE */
 
-/* Define to 1 if you have the <unistd.h> header file. */
-//#define HAVE_UNISTD_H 1
-
 /* Define to 1 if you have the <X11/Intrinsic.h> header file. */
 /* #undef HAVE_X11_INTRINSIC_H */
 
@@ -250,29 +232,17 @@
 /* Define to the version of this package. */
 #define PACKAGE_VERSION VERSION
 
-/* Path separator character. */
-#define PATHSEPARATOR ":"
-
 /* Define if you want SFDP */
 #define SFDP 1
 /* #undef SFDP */
 
-/* Define if you want SMYRNA */
-/* #undef SMYRNA */
-
 /* Define if you want CGRAPH */
 #define WITH_CGRAPH 1
 
-/* Define to 1 if the X Window System is missing or not being used. */
-#define X_DISPLAY_MISSING 1
-
 /* Define to 1 if `lex' declares `yytext' as a `char *' by default, not a
    `char[]'. */
 /* #undef YYTEXT_POINTER */
 
-/* Define to `int' if <sys/types.h> doesn't define. */
-#define gid_t int
-
 /* Define to `int' if <sys/types.h> does not define. */
 /* #undef pid_t */
 
